@@ -18,13 +18,13 @@
 #include "tool.h"
 #include "deviceTypes.h"
 #include "busOutputArray.h"
-#include "symbolOpStack.h"
+#include "symbolicCalc.h"
 
 /***************************************************/
 /* static methods of Device                        */
 /***************************************************/
 int Device::STATcnt[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
-const char * Device::STATtext[] = {"and", "or", "inv", "xor", "7s", "switch", "osc", "", "rs", "d",
+QString Device::STATname[] = {"and", "or", "inv", "xor", "7s", "switch", "osc", "", "rs", "d",
 			     "jk", "led", "in", "out", "net", "pwr", "text", "sub", "led", "led",
 			     "led", "tri", "ram", ""};
 int Device::STATdef_delay = Device::DEFAULT_DELAY;
@@ -114,10 +114,8 @@ Device::Device(int func, int del, int undef, int clock)
 
 	id = uniqueID::getID();
 
-	// these counters are only used to get a new name!
-	char buf[101];
-	sprintf(buf, "%s%d", STATtext[func - DeviceType::fBASE], ++STATcnt[func - DeviceType::fBASE]);
-	text = buf;
+	m_sName = STATname[func - DeviceType::fBASE];
+	m_sName += QString::number(++STATcnt[func - DeviceType::fBASE]);
 
 	function = func;
 
@@ -170,12 +168,10 @@ Device::Device(int func, int del, int undef, int clock)
 
 	// the first output in the list of outputs is an unnamed output, each device can use
 	// it can be reached by "named_output.Get()->"
-	opStack *op = new opStack(this, undef_value, delay);
+	Calculator *op = new Calculator(this, undef_value, delay);
 	op->setPosition(-1);
 	named_output.Append(op);
 
-	static_input_value = 0;
-
 	// no of active tristate outputs
 	tristate = 0;
 	tristate_active = false;
@@ -202,7 +198,7 @@ Device::~Device()
 	}
 	named_input.Destroy();
 
-	KlogicList<opStack> *o = named_output.First();
+	KlogicList<Calculator> *o = named_output.First();
 	while(o) {
 		delete o->Get();
 		o = o->Next();
@@ -253,35 +249,35 @@ void Device::setMaster(int newi)
 	parseEquation();
 }
 
-const char * Device::getText(int nospace)
+QString Device::getName(bool bNoSpace) const
 {	
-	static QString ret;
+	QString ret;
 
-	if (!nospace) return (const char *)text;
-
-	ret = text;
+	if (!bNoSpace)
+		return m_sName;
+	ret = m_sName;
 	ret.replace(QRegExp(" "), "_" );
-	return (const char *)ret;
+	return ret;
 }
 
-void Device::setText(const QString& new_text)
+void Device::setName(const QString& sName)
 {
-	text = new_text;
+	m_sName = sName;
 }
 
 // return true if output is at low resistance
-bool Device::outputIsActive(int output_id)
+bool Device::outputIsActive(int iOutputId)
 {
-	KlogicList<opStack> *op = named_output.With(output_id);
+	KlogicList<Calculator> *op = named_output.With(iOutputId);
 	if (op->Get()->getResult() == TRISTATE) return false;
 	return true;
 }
 
 // enable/disable tristate mode for a single output
 // make sure there is an "EN" input available!
-void Device::outputSetTristate(int output_id, bool flag)
+void Device::outputSetTristate(int iOutputId, bool flag)
 {
-	KlogicList<opStack> *op = named_output.With(output_id);
+	KlogicList<Calculator> *op = named_output.With(iOutputId);
 	if (op && op->Get()) {
 		if (op->Get()->isInternal()) return;
 		if (flag && op->Get()->isTristate()) return;
@@ -295,9 +291,9 @@ void Device::outputSetTristate(int output_id, bool flag)
 }
 
 // return tristate mode for a single output
-bool Device::outputIsTristate(int output_id)
+bool Device::outputIsTristate(int iOutputId)
 {
-	KlogicList<opStack> *op = named_output.With(output_id);
+	KlogicList<Calculator> *op = named_output.With(iOutputId);
 	if (op) return op->Get()->isTristate();
 	return false;
 }
@@ -305,7 +301,7 @@ bool Device::outputIsTristate(int output_id)
 // enable/disable tristate mode for the complete device
 void Device::setTristate(bool flag)
 {
-	KlogicList<opStack> *op = named_output.First();
+	KlogicList<Calculator> *op = named_output.First();
 	while(op) {
 		outputSetTristate(op->getID1(), flag);
 		op = op->Next();
@@ -328,19 +324,19 @@ bool Device::isTristateControlInput(int input_id)
 // connect two devices
 //	out_dev:   connected device
 //	input_id:  id of this named input
-//	output_id: id of out_dev's named output
-int Device::connectDevices(Device *out_dev, int input_id, int output_id)
+//	iOutputId: id of out_dev's named output
+int Device::connectDevices(Device *out_dev, int input_id, int iOutputId)
 {
-	//fprintf(stdout, "connect %s(%d) --> %s(%d)\n", out_dev->getText(), output_id, getText(), input_id);
-	if (!connection_list.Append(out_dev, input_id, output_id)) return 0;
+	//fprintf(stdout, "connect %s(%d) --> %s(%d)\n", out_dev->getName(), iOutputId, getName(), input_id);
+	if (!connection_list.Append(out_dev, input_id, iOutputId)) return 0;
 	return 1;
 }
 
 // disconnect two devices
-int Device::disconnectDevices(Device *out_dev, int input_id, int output_id)
+int Device::disconnectDevices(Device *out_dev, int input_id, int iOutputId)
 {
-	//fprintf(stdout, "disconnect %s(%d) --> %s(%d)\n", out_dev->getText(), output_id, getText(), input_id);
-	if (!connection_list.Destroy(out_dev, input_id, output_id)) return 0;
+	//fprintf(stdout, "disconnect %s(%d) --> %s(%d)\n", out_dev->getName(), iOutputId, getName(), input_id);
+	if (!connection_list.Destroy(out_dev, input_id, iOutputId)) return 0;
 	return 1;
 }
 
@@ -359,14 +355,6 @@ void Device::changeLEDType(int new_type) {
 	function = new_type;
 }
 
-// static: devices with user interaction
-int Device::isInteractive()
-{	
-	if (function == DeviceType::fSWI)
-		return 1;
-	return 0;
-}
-
 // check if name is unused
 bool Device::inputNameIsUnique(QString& input_name)
 {
@@ -405,40 +393,40 @@ void Device::removeInputName(int input_id)
 // add a new named output for this device
 // pos contains the the position (GRID times related to device-image) of the named output device
 // the input_id is used for import purposes!
-int Device::addOutputName(const QString& name, int pos, int output_id)
+int Device::addOutputName(const QString& name, int pos, int iOutputId)
 {
-	opStack *op = new opStack(this, undef(), delay());
+	Calculator *op = new Calculator(this, undef(), delay());
 	op->setPosition(pos);
-	if (!output_id) output_id = uniqueID::getID();
-	named_output.Append(op, output_id)->setText(name);
-	if (tristate) outputSetTristate(output_id, true);
-	return output_id;
+	if (!iOutputId) iOutputId = uniqueID::getID();
+	named_output.Append(op, iOutputId)->setText(name);
+	if (tristate) outputSetTristate(iOutputId, true);
+	return iOutputId;
 }
 
 // change the name of an output
-int Device::changeOutputName(int output_id, const QString& new_name)
+int Device::changeOutputName(int iOutputId, const QString& new_name)
 {	
-	KlogicList<opStack> *op = named_output.With(output_id);
+	KlogicList<Calculator> *op = named_output.With(iOutputId);
 	if (op) {
 		op->setText(new_name);
 	}
-	return output_id;
+	return iOutputId;
 }
 
 // remove a named output from this device
-void Device::removeOutputName(int output_id)
+void Device::removeOutputName(int iOutputId)
 {
-	KlogicList<opStack> *op = named_output.With(output_id);
+	KlogicList<Calculator> *op = named_output.With(iOutputId);
 	if (op && op != named_output.First()) {
-		if (tristate) outputSetTristate(output_id, false);
+		if (tristate) outputSetTristate(iOutputId, false);
 		delete op->Get();
-		named_output.Destroy(output_id);
+		named_output.Destroy(iOutputId);
 	}
 }
 
 // return the name of an output id (equation devices: unique names!)
-const char * Device::getOutputName(int output_id)
-{	KlogicList<opStack> *lop = named_output.With(output_id);
+const char * Device::getOutputName(int iOutputId)
+{	KlogicList<Calculator> *lop = named_output.With(iOutputId);
 
 	if (lop) return lop->getText();
 	return (char *)NULL;
@@ -454,22 +442,22 @@ int Device::getInputID(QString& input_name)
 
 // return the name of an output id (equation devices: unique names!)
 int Device::getOutputID(QString& output_name)
-{	KlogicList<opStack> *lop = named_output.With(output_name);
+{	KlogicList<Calculator> *lop = named_output.With(output_name);
 
 	if (lop) return lop->getID1();
 	return 0;
 }
 
 // change type of output
-void Device::setOutputNameType(int output_id, int new_type)
-{	KlogicList<opStack> *op = named_output.With(output_id);
+void Device::setOutputNameType(int iOutputId, int new_type)
+{	KlogicList<Calculator> *op = named_output.With(iOutputId);
 
 	if (op && op->Get()) {
 		if (new_type == INTERNAL_OUTPUT) {
-			if (tristate) outputSetTristate(output_id, false);
+			if (tristate) outputSetTristate(iOutputId, false);
 			op->Get()->setInternal(true);
 		} else {
-			if (tristate) outputSetTristate(output_id, true);
+			if (tristate) outputSetTristate(iOutputId, true);
 			op->Get()->setInternal(false);
 		}
 	}
@@ -479,7 +467,7 @@ void Device::setOutputNameType(int output_id, int new_type)
 int Device::addInternalName(const QString& name)
 {	int int_id = uniqueID::getID();
 
-	opStack *op = new opStack(this, undef(), delay());
+	Calculator *op = new Calculator(this, undef(), delay());
 	op->setInternal(true);
 	op->setPosition(0);
 	named_output.Append(op, int_id)->setText(name);
@@ -488,7 +476,7 @@ int Device::addInternalName(const QString& name)
 
 // returns wether id is an internal output name, or should be final or temporary
 int Device::suggestedOutputType(int internal_id)
-{	KlogicList<opStack> *op = named_output.With(internal_id);
+{	KlogicList<Calculator> *op = named_output.With(internal_id);
 
 	if (op && op->Get()->isInternal()) return INTERNAL_OUTPUT;
 	if (type() == DeviceType::fLEDred ||
@@ -515,7 +503,7 @@ KlogicList<Value> * Device::getNamedIRef()
 	return &named_input;
 }
 
-KlogicList<opStack> * Device::getNamedORef()
+KlogicList<Calculator> * Device::getNamedORef()
 {
 	return &named_output;
 }
@@ -541,32 +529,9 @@ bool Device::hasNamedOutput()
 	return false;
 }
 
-bool Device::hasStaticInput()
-{
-	if (function == DeviceType::fSWI || function == DeviceType::fPWR) return true;
-	return false;
-}
-
 // set static output-value
-void Device::toggleStaticInput()
-{
-	if (static_input_value) static_input_value = 0;
-	else static_input_value = 1;
-	named_output.Get()->flush(static_input_value);
-	forceOutputChange();
-}
-
-// set static input-value
-void Device::setStaticInput(int val)
-{
-	static_input_value = val;
-	named_output.Get()->flush(static_input_value);
-	forceOutputChange();
-}
-
-// set static output-value
-void Device::setStaticOutput(int output_id, int val)
-{	KlogicList<opStack> *lop = named_output.With(output_id);
+void Device::setStaticOutput(int iOutputId, int val)
+{	KlogicList<Calculator> *lop = named_output.With(iOutputId);
 
 	if (lop && lop->Get()) {
 		if (lop->Get()->getResult() != val) {
@@ -579,7 +544,7 @@ void Device::setStaticOutput(int output_id, int val)
 		return;
 	}
 	lop = named_output.First();
-	fatal("Device::setStaticOutput: unknown static output %d\n", output_id);
+	fatal("Device::setStaticOutput: unknown static output %d\n", iOutputId);
 }
 
 bool Device::hasClock()
@@ -603,7 +568,7 @@ int Device::getID()
 // set value for undefined outputs
 void Device::setUndef(int undef)
 {
-	KlogicList<opStack> *lo = named_output.First();
+	KlogicList<Calculator> *lo = named_output.First();
 	while(lo) {
 		lo->Get()->setUndefined(undef);
 		lo = lo->Next();
@@ -618,7 +583,7 @@ int Device::undef()
 // set signal delay
 void Device::setDelay(int d)
 {
-	KlogicList<opStack> *lop = named_output.First();
+	KlogicList<Calculator> *lop = named_output.First();
 	while(lop) {
 		lop->Get()->setDelay(d);
 		lop = lop->Next();
@@ -627,37 +592,49 @@ void Device::setDelay(int d)
 
 int Device::delay()
 {
-	return named_output.Get()->delay();
+	return named_output.Get()->getDelay();
 }
 
 // return input value
-// tristateckeck is related to an output for which this method is called
+// tristate check is related to an output for which this method is called
 // so it has nothing to do with the input value returned
 // changed: using OR function when having more than one connection to a single input
 int Device::input(int input_id)
-{	bool tristate_found = false;
-	bool value_found = false;
-	int value = 0;
+{
+	bool bUnused;
+	return input(input_id, bUnused);
+}
 
+int Device::input(int input_id, bool& bIsBoolean)
+{	bool bTristateFound = false;
+	bool bValueFound = false;
+	int iValue = 0;
+
+	bIsBoolean = true;
 	KlogicList<Device> *l = connection_list.With(input_id);
 	while(l) {
-		int _value = l->Get()->output(l->getID2());
-		if (_value == TRISTATE) {
-			tristate_found = true;	// return another value if possible
+		Device *d = l->Get();
+		int iOutputID = l->getID2();
+
+		int _iValue = d->output(iOutputID);
+		if (_iValue == TRISTATE) {
+			bTristateFound = true;	// return another value if possible
 		} else {
-			value |= _value;
-			value_found = true;
+			iValue |= _iValue;
+			bValueFound = true;
 		}
+		if (!(d->hasBooleanOutput(iOutputID)))
+			bIsBoolean = false;
 		l = l->NextWith(input_id);
 	}
-	if (value_found) return value;
-	if (tristate_found) return TRISTATE;
+	if (bValueFound) return iValue;
+	if (bTristateFound) return TRISTATE;
 
 	return 0;	// no input value
 }
 
 // return output value
-int Device::output(int output_id)
+int Device::output(int iOutputId)
 {
 	// internal inverter device
 	if (function == DeviceType::fINV_INTERNAL) {
@@ -673,12 +650,12 @@ int Device::output(int output_id)
 		}
 	}
 
-	return named_output.With(output_id)->Get()->getResult();
+	return named_output.With(iOutputId)->Get()->getResult();
 }
 
 void Device::flush(int value)
 {
-	KlogicList<opStack> *lop = named_output.First();
+	KlogicList<Calculator> *lop = named_output.First();
 	while(lop) {
 		lop->Get()->flush(value);
 		lop = lop->Next();
@@ -695,20 +672,16 @@ int Device::outputChanged()
 {
 	if (force_output_changed) return 1;
 	if (new_result != old_result) return 1;
-	//if (function == fIN) return 1;
 	return 0;
 }
 
 // calculate new output-values (old value at output visible)
 void Device::Calculate(int)
-{	KlogicList<opStack> *lop;
-	opStack *op;
+{	KlogicList<Calculator> *lop;
+	Calculator *op;
 	KlogicList<Device> *l;
 	int val;
 
-	// no calculation
-	if (function == DeviceType::fTXT || function == DeviceType::fIN) return;
-
 	// check wether tristate input is active or not
 	if (tristate) {
 		KlogicList<Device> *l_en = connection_list.With(tristate_enable_id);
@@ -727,18 +700,14 @@ void Device::Calculate(int)
 	while(lop) {
 		op = lop->Get();
 		// static operation devices: push all input values to the calculation stack
-		if (op->hasStaticOP()) {
-			if (function == DeviceType::fIN || function == DeviceType::fSWI || function == DeviceType::fPWR) {
-				op->push(static_input_value);
-			} else {
-				// e.g. the AND gate
-				l = connection_list.First();
-				while(l) {
-					// id2: id of the named output of the connected device
-					val = l->Get()->output(l->getID2());
-					op->push(val);
-					l = l->Next();
-				}
+		if (op->isStatic()) {
+			// e.g. the AND gate
+			l = connection_list.First();
+			while(l) {
+				// id2: id of the named output of the connected device
+				val = l->Get()->output(l->getID2());
+				op->push(val);
+				l = l->Next();
 			}
 		}
 
@@ -752,11 +721,8 @@ void Device::Calculate(int)
 // most of it is detection of output changes .. (to be optimized?)
 void Device::Propagate(int burst_step)
 {
-	// no calculation
-	if (function == DeviceType::fTXT || function == DeviceType::fIN) return;
-
 	// switch all outputs
-	KlogicList<opStack> *lop = named_output.First();
+	KlogicList<Calculator> *lop = named_output.First();
 	if (force_output_changed) {
 		new_result = 1;
 		old_result = 0;
@@ -799,10 +765,20 @@ void Device::Propagate(int burst_step)
 	}
 }
 
-// return equation string for an output
-QString Device::getEquation(int output_id)
+const KlogicList<Calculator> * Device::getOutput(const QString& sName)
 {
-	KlogicList<opStack> *lo = named_output.With(output_id);
+	return named_output.With(sName);
+}
+
+const KlogicList<Value> * Device::getInput(const QString& sName)
+{
+	return named_input.With(sName);
+}
+
+// return equation string for an output
+QString Device::getEquation(int iOutputId)
+{
+	KlogicList<Calculator> *lo = named_output.With(iOutputId);
 	if (lo) return lo->Get()->getEquation();
 	else return QString("");
 }
@@ -835,7 +811,7 @@ void Device::setEquation()
 
 	switch(function) {
 	case DeviceType::fONE:
-		setEquation(OP_NONE);
+		setEquation(Operator::NONE);
 		break;
 	case DeviceType::fTRI:
 		setEquation("D0", (*output_bus)[0]);
@@ -847,35 +823,20 @@ void Device::setEquation()
 		setEquation("D6", (*output_bus)[6]);
 		setEquation("D7", (*output_bus)[7]);
 		break;
-	case DeviceType::fPWR:
-		setEquation(OP_NONE);
-		break;
-	case DeviceType::fSWI:
-		setEquation(OP_NONE);
-		break;
-	case DeviceType::fTXT:
-		setEquation(OP_NONE);
-		break;
-	case DeviceType::fIN:
-		setEquation(OP_INTERFACE);
-		break;
-	case DeviceType::fOUT:
-		setEquation(OP_INTERFACE);
-		break;
 	case DeviceType::fXOR:
-		setEquation(OP_XOR);
+		setEquation(Operator::XOR);
 		break;
 	case DeviceType::fAND:
-		setEquation(OP_AND);
+		setEquation(Operator::AND);
 		break;
 	case DeviceType::fOR:
-		setEquation(OP_OR);
+		setEquation(Operator::OR);
 		break;
 	case DeviceType::fLEDred:
 	case DeviceType::fLEDblue:
 	case DeviceType::fLEDgreen:
 	case DeviceType::fLEDyellow:
-		setEquation(OP_OR);
+		setEquation(Operator::OR);
 		break;
 	case DeviceType::fSS:
 		setEquation("2^0  2^1  2^2  2^3");
@@ -978,78 +939,73 @@ void Device::setEquation(char _new_equation)
 }
 
 // set equation string for an output
-void Device::setEquation(const char *_new_equation, int output_id)
-{	KlogicList<opStack> *lo;
+void Device::setEquation(const char *_new_equation, int iOutputId)
+{	KlogicList<Calculator> *lo;
 
-	if (!output_id) lo = named_output.First();
-	else lo = named_output.With(output_id);
+	if (!iOutputId) lo = named_output.First();
+	else lo = named_output.With(iOutputId);
 
 	if (lo) lo->Get()->setEquation(_new_equation);
 }
 
 // parse all equations, build the calculation stacks for this device
 QueueInfo Device::parseEquation()
-{	KlogicList<opStack> *lo = named_output.First();
-	QueueInfo ret;
+{	KlogicList<Calculator> *lo = named_output.First();
 
 	while(lo) {
-		ret = lo->Get()->parse(&named_input, &named_output);
-		if (ret.no) {
-			// error <no> occured at <position> and <length>
-			ret.output_name = lo->getText();
-			ret.output_id = lo->getID1();
-			return ret;
-		}
-		lo = lo->Next();
-	}
-	return ret;
-}
-
-// clear all calculation stacks for this device
-void Device::resetParsing()
-{	KlogicList<opStack> *lo = named_output.First();
-
-	while (lo) {
-		lo->Get()->clear();
+		const QueueInfo& oQI = lo->Get()->parse();
+		if (oQI.m_iError != QueueInfo::NOERR)
+			return oQI;
 		lo = lo->Next();
 	}
+	return QueueInfo();
 }
 
 // deliveres a string like [/][qualifier_prefix.]devicename[.outputname]
 // depends on the given device and output name
 QString Device::qualifiedOutputName(Device *dev, const char *out_name, const char *qual_pref)
 {	QString buf;
-	const char *new_out_name;
 	KlogicList<Device> *li;
-	int dbl_inv = 0;
 
-	const char *prefix=(char *)qual_pref;
-	if (!prefix) prefix = "";
-	buf[0] = 0;
+	QString prefix;
+	if (qual_pref)
+		prefix = qual_pref;
 
 	if (dev->type() == DeviceType::fINV_INTERNAL) {
+		bool bDoubleInv = false;
 		li = dev->connection_list.First();
 		if (li) {
 			if (li->Get()->type() == DeviceType::fINV_INTERNAL) {
 				li = li->Get()->connection_list.First();
-				dbl_inv = 1;
+				bDoubleInv = true;
 			}
 		}
 		if (li) {
-			new_out_name = li->getText();
+			const QString& new_out_name = li->getText();
 			if (new_out_name && strlen(new_out_name)) {
-				if (dbl_inv) buf.sprintf("%s%s.%s", prefix, li->Get()->getText(NOSPACE), new_out_name);
-				else buf.sprintf("/%s%s.%s", prefix, li->Get()->getText(NOSPACE), new_out_name);
+				if (!bDoubleInv)
+					buf.append('/');
+				buf.append(prefix);
+				buf.append(li->Get()->getName(NOSPACE));
+				buf.append('.');
+				buf.append(new_out_name);
 			} else {
-				if (dbl_inv) buf.sprintf("%s%s", prefix, li->Get()->getText(NOSPACE));
-				else buf.sprintf("/%s%s", prefix, li->Get()->getText(NOSPACE));
+				if (!bDoubleInv)
+					buf.append('/');
+				buf.append(prefix);
+				buf.append(li->Get()->getName(NOSPACE));
 			}
 		}
 	} else {
-		if (out_name && strlen(out_name))
-			buf.sprintf("%s%s.%s", prefix, dev->getText(NOSPACE), out_name);
-		else
-			buf.sprintf("%s%s", prefix, dev->getText(NOSPACE));
+		if (out_name && strlen(out_name)) {
+			buf.append(prefix);
+			buf.append(dev->getName(NOSPACE));
+			buf.append('.');
+			buf.append(out_name);
+		} else {
+			buf.append(prefix);
+			buf.append(dev->getName(NOSPACE));
+		}
 	}
 
 	// remove all spaces from the used names!
@@ -1061,39 +1017,33 @@ QString Device::qualifiedOutputName(Device *dev, const char *out_name, const cha
 }
 
 // append all equations of this device to the given list
-// the qualifier will be appended to each name and equation
-// isolate: just look at this device, not outside
-void Device::getAllEquations(KlogicList<OutputInfo> *ls, const char *qualifier, bool isolate)
+// sQPrefix will be appended to each name in all equations
+// bIsolate: just look at this device, not outside
+void Device::getAllEquations(map<QString,OutputInfo>& oEquations, const QString& sQPrefix, bool bIsolate)
 {	KlogicList<Device> *lconn;
 	KlogicList<Value> *li;
-	KlogicList<opStack> *lo;
-	QString qual_pref;
-	QString final;
-	bool ffinal;
-
-	if (!ls) fatal("Device::getAllEquations: no list??\n");
-
-	if (qualifier) qual_pref = qualifier;
-	else qual_pref = "";
+	KlogicList<Calculator> *lo;
+	QString sFinal;
+	bool bFinal;
 
 	// remember the interface circuits
-	if (!qualifier && function == DeviceType::fOUT ||
+	if (sQPrefix.isEmpty() && function == DeviceType::fOUT ||
 	                  function == DeviceType::fSS ||
 			  function == DeviceType::fLEDred ||
 			  function == DeviceType::fLEDblue ||
 			  function == DeviceType::fLEDgreen ||
 			  function == DeviceType::fLEDyellow) {
-		final = "(final)";
-		ffinal = true;
+		sFinal = "(final)";
+		bFinal = true;
 	} else {
-		final = "";
-		ffinal = false;
+		sFinal = "";
+		bFinal = false;
 	}
 
 	if (hasNamedInput()) {
 		// device has named inputs
 
-		if (!isolate) {
+		if (!bIsolate) {
 			// build artificial output for each input
 			li = named_input.First();
 			while(li) {
@@ -1104,16 +1054,16 @@ void Device::getAllEquations(KlogicList<OutputInfo> *ls, const char *qualifier,
 				while(lconn) {
 					if (li->getID1() == lconn->getID1()) {
 						if (!connected) {
-							eq = qualifiedOutputName(lconn->Get(), lconn->Get()->getOutputName(lconn->getID2()), qual_pref);
+							eq = qualifiedOutputName(lconn->Get(), lconn->Get()->getOutputName(lconn->getID2()), sQPrefix);
 							connected = 1;
 						} else if (connected == 1) {
 							eq = "(" + eq + ") + (";
-							eq += qualifiedOutputName(lconn->Get(), lconn->Get()->getOutputName(lconn->getID2()), qual_pref);
+							eq += qualifiedOutputName(lconn->Get(), lconn->Get()->getOutputName(lconn->getID2()), sQPrefix);
 							eq += ")";
 							connected = 2;
 						} else {
 							eq += " + (";
-							eq += qualifiedOutputName(lconn->Get(), lconn->Get()->getOutputName(lconn->getID2()), qual_pref);
+							eq += qualifiedOutputName(lconn->Get(), lconn->Get()->getOutputName(lconn->getID2()), sQPrefix);
 							eq += ")";
 						}
 
@@ -1121,16 +1071,16 @@ void Device::getAllEquations(KlogicList<OutputInfo> *ls, const char *qualifier,
 					lconn = lconn->Next();
 				}
 				if (connected) {
-					OutputInfo *oi = new OutputInfo();
-					oi->device_id = this->getID();
-					oi->output_id = 0;
-					oi->output_name = qualifiedOutputName(this, li->getText(), qual_pref);
-					oi->original_output_name = qualifiedOutputName(this, li->getText(), qual_pref);
-					oi->output_type = INPUT;
-					oi->equation = eq;
-					oi->prefix = qual_pref;
-					oi->suffix = final;
-					ls->Append(oi)->setText(oi->output_name);
+					OutputInfo oi;
+					oi.device_id = this->getID();
+					oi.output_id = 0;
+					oi.output_name = qualifiedOutputName(this, li->getText(), sQPrefix);
+					oi.original_output_name = qualifiedOutputName(this, li->getText(), sQPrefix);
+					oi.output_type = INPUT;
+					oi.equation = eq;
+					oi.prefix = sQPrefix;
+					oi.suffix = sFinal;
+					oEquations[oi.output_name] = oi;
 				}
 
 				li = li->Next();
@@ -1142,49 +1092,49 @@ void Device::getAllEquations(KlogicList<OutputInfo> *ls, const char *qualifier,
 	lo = named_output.First();
 	while(lo) {
 		if (lo->Get()->hasEquation()) {
-			QString qual;
+			QString sQualifier = sQPrefix;
+			if (!bIsolate) {
+				sQualifier.append(getName(NOSPACE));
+				sQualifier.append('.');
+			}
 
-			if (!isolate) qual = qual_pref + this->getText(NOSPACE) + ".";
-			else qual = qual_pref;
-
-			OutputInfo *oi = new OutputInfo();
-			oi->device_id = getID();
-			oi->output_id = lo->getID1();
-			if (lo->Get()->hasStaticOP()) {
+			OutputInfo oi;
+			oi.device_id = getID();
+			oi.output_id = lo->getID1();
+			if (lo->Get()->isStatic()) {
 				// concatenate all inputs with the static operation
 				lconn = connection_list.First();
 				while(lconn) {
-					oi->equation += qualifiedOutputName(lconn->Get(), lconn->Get()->getOutputName(lconn->getID2()), qual_pref);
+					oi.equation.append(qualifiedOutputName(lconn->Get(), lconn->Get()->getOutputName(lconn->getID2()), sQPrefix));
 					lconn = lconn->Next();
 					if (lconn) {
-						oi->equation += " ";
-						oi->equation += lo->Get()->getEquation();	// the static operation
-						oi->equation += " ";
+						oi.equation.append(" ");
+						oi.equation.append(lo->Get()->getEquation());	// the static operation
+						oi.equation.append(" ");
 					}
 				}
 			} else {
-				// the opStack instance has the equation
-				oi->equation = lo->Get()->getEquation(qual);
+				// the Calculator instance has the equation
+				oi.equation = lo->Get()->getEquation(sQualifier);
 			}
-			if (!isolate) {
-				oi->output_name = qualifiedOutputName(this, lo->getText(), qual_pref);
-				oi->original_output_name = qualifiedOutputName(this, lo->getText(), qual_pref);
+			if (!bIsolate) {
+				oi.output_name = qualifiedOutputName(this, lo->getText(), sQPrefix);
+				oi.original_output_name = qualifiedOutputName(this, lo->getText(), sQPrefix);
 			} else {
-				oi->output_name = lo->getText();
-				oi->original_output_name = lo->getText();
+				oi.output_name = lo->getText();
+				oi.original_output_name = lo->getText();
 			}
-			if (!isolate) {
-				if (ffinal) oi->output_type = FINAL_OUTPUT;
-				else oi->output_type = suggestedOutputType(oi->output_id);
+			if (!bIsolate) {
+				if (bFinal) oi.output_type = FINAL_OUTPUT;
+				else oi.output_type = suggestedOutputType(oi.output_id);
 			} else {
-				if (ffinal) oi->output_type = FINAL_OUTPUT;
-				else if (suggestedOutputType(oi->output_id) != INTERNAL_OUTPUT) oi->output_type = FINAL_OUTPUT;
-				else oi->output_type = INTERNAL_OUTPUT;
+				if (bFinal) oi.output_type = FINAL_OUTPUT;
+				else if (suggestedOutputType(oi.output_id) != INTERNAL_OUTPUT) oi.output_type = FINAL_OUTPUT;
+				else oi.output_type = INTERNAL_OUTPUT;
 			}
-			oi->prefix = qual_pref;
-			oi->suffix = final;
-			//fprintf(stdout, "%s(%s)\n", (const char *)(oi->output_name), (const char *)(oi->suffix));
-			ls->Append(oi)->setText(oi->output_name);
+			oi.prefix = sQPrefix;
+			oi.suffix = sFinal;
+			oEquations[oi.output_name] = oi;
 		}
 		lo = lo->Next();
 	}
@@ -1205,7 +1155,7 @@ void Device::setAllEquations(KlogicList<OutputInfo> *equations, bool change_size
 		l = l->Next();
 	}
 
-	KlogicList<opStack> *lo;
+	KlogicList<Calculator> *lo;
 	lo = named_output.First();
 	while(lo) {
 		if (lo->Get()->hasEquation()) {
@@ -1222,8 +1172,6 @@ void Device::setAllEquations(KlogicList<OutputInfo> *equations, bool change_size
 	KlogicList<QString> all_outputs;
 	KlogicList<QString> new_outputs;
 	KlogicList<OutputInfo> *lout_new = equations->First();
-	int output_id;
-	QString output;
 	while(lout_new) {
 		all_outputs.Append((QString *)&dummy)->setText(lout_new->Get()->output_name);
 		int id = getOutputID(lout_new->Get()->output_name);
@@ -1237,31 +1185,31 @@ void Device::setAllEquations(KlogicList<OutputInfo> *equations, bool change_size
 	// -------------------------------------------------------
 	// replace/remove output vars
 	// -------------------------------------------------------
-	KlogicList<opStack> *lop = named_output.First()->Next();
+	KlogicList<Calculator> *lop = named_output.First()->Next();
 	KlogicList<QString> *lnew = new_outputs.First();
 	OutputInfo *oi;
 	while (lop) {
-		output_id = lop->getID1();
-		output = lop->getText();
+		int iOutputId = lop->getID1();
+		const QString& sOutput = lop->getText();
 		lop = lop->Next();
 
-		if (!all_outputs.With(output)) {
+		if (!all_outputs.With(sOutput)) {
 			if (lnew) {
 				// replace old output with a new one
 				oi = equations->Get(lnew->getText());
-				output_id = changeOutputName(output_id, oi->output_name);
-				setEquation(oi->equation, output_id);
-				setOutputNameType(output_id, oi->output_type);
+				iOutputId = changeOutputName(iOutputId, oi->output_name);
+				setEquation(oi->equation, iOutputId);
+				setOutputNameType(iOutputId, oi->output_type);
 				lnew = lnew->Next();
 			} else {
 				// nothing to replace: remove old output
-				removeOutputName(output_id);
+				removeOutputName(iOutputId);
 			}
 		} else {
-			oi = equations->Get(output);
-			output_id = changeOutputName(output_id, oi->output_name);
-			setEquation(oi->equation, output_id);
-			setOutputNameType(output_id, oi->output_type);
+			oi = equations->Get(sOutput);
+			iOutputId = changeOutputName(iOutputId, oi->output_name);
+			setEquation(oi->equation, iOutputId);
+			setOutputNameType(iOutputId, oi->output_type);
 		}
 	}
 
@@ -1270,11 +1218,11 @@ void Device::setAllEquations(KlogicList<OutputInfo> *equations, bool change_size
 	// -------------------------------------------------------
 	while(lnew) {
 		if (change_size) setSize(neededSize() + 1);
-		output = lnew->getText();
-		oi = equations->Get(output);
-		output_id = changeOutputName(0, oi->output_name);
-		setEquation(oi->equation, output_id);
-		setOutputNameType(output_id, oi->output_type);
+		const QString& sOutput = lnew->getText();
+		oi = equations->Get(sOutput);
+		int iOutputId = changeOutputName(0, oi->output_name);
+		setEquation(oi->equation, iOutputId);
+		setOutputNameType(iOutputId, oi->output_type);
 		lnew = lnew->Next();
 	}
 
@@ -1287,13 +1235,13 @@ void Device::setAllEquations(KlogicList<OutputInfo> *equations, bool change_size
 	KlogicList<QString> new_inputs;
 	while(lout_new) {
 		// create a list of all symbols available in equation
-		SymbolOpStack oop;
+		SymbolicCalc oop;
 		oop.setEquation(lout_new->Get()->equation);
 		oop.parse();
 
 		int i = 0;
 		while(NULL != (input = oop.getSymbol(i++))) {
-			if (!opStack::isNumber(input)) {
+			if (!Calculator::isNumber(input)) {
 				if (!new_inputs.With(input) && !equations->With(input) && inputNameIsUnique(input))
 					new_inputs.Append((QString *)&dummy)->setText((const char *)input);
 				if (!all_inputs.With(input))
