@@ -24,10 +24,10 @@
 
 #include "klogic.h"
 #include "netw.h"
-#include "xnet.h"
+#include "circuit.h"
 #include "dlgEqu.h"
 #include "dlgPattern.h"
-#include "symbolOpStack.h"
+#include "symbolicCalc.h"
 #include "deviceTypes.h"
 
 #include "dlgEqu.moc"
@@ -42,7 +42,7 @@ const char * DlgEqu::TYPE_NONE = "";
 // -----------------------------------------
 // circuit equation editing / device creator
 // -----------------------------------------
-DlgEqu::DlgEqu(QWidget *parent, QString _caption, XDeviceNet *_net)
+DlgEqu::DlgEqu(QWidget *parent, QString _caption, Circuit *_net)
 	: QDialog(parent, _caption, TRUE, WStyle_DialogBorder)
 {
     net = _net;
@@ -64,7 +64,7 @@ DlgEqu::DlgEqu(QWidget *parent, QString _caption, XDeviceNet *_net)
 DlgEqu::DlgEqu(QWidget *parent, QString _caption, XDevice *_dev)
 	: QDialog(parent, _caption, TRUE, WStyle_DialogBorder)
 {
-    net = (XDeviceNet *)NULL;
+    net = (Circuit *)NULL;
     dev = _dev;
 
     equations = (KlogicList<OutputInfo> *)NULL;
@@ -297,7 +297,7 @@ void DlgEqu::done(int r)
 			lout = equations->First();
 			while(lout) {
 				// create a list of all available symbols
-				SymbolOpStack oop;
+				SymbolicCalc oop;
 				oop.setEquation(lout->Get()->equation);
 				oop.parse();
 
@@ -510,7 +510,7 @@ void DlgEqu::normalizeEquation()
 {
 	if (!edit_equation->text().length()) return;
 
-	SymbolOpStack opp;
+	SymbolicCalc opp;
 	// build result table
 	opp.setEquation(edit_equation->text());
 	opp.parse();
@@ -552,7 +552,6 @@ int DlgEqu::changeOutputName(QString old_name, QString new_name)
 void DlgEqu::replaceString()
 {	QString s_old, s_new;
 	int start, len, new_len;
-	int found = 0;
 
 	s_old = edit_replace->text();
 	s_new = edit_replace_with->text();
@@ -562,27 +561,28 @@ void DlgEqu::replaceString()
 	if (!len) return;
 
 	KlogicList<OutputInfo> *ls = equations->First();
+	bool bFound = false;
 	while(ls) {
 		start = 0;
 		while (-1 != (start = ls->Get()->equation.find(s_old, start))) {
 			ls->Get()->equation.replace(start, len, s_new);
 			start += new_len;
-			found = 1;
+			bFound = true;
 		}
 		start = 0;
 		while (-1 != (start = ls->Get()->output_name.find(s_old, start))) {
 			ls->Get()->output_name.replace(start, len, s_new);
 			start += new_len;
-			found = 1;
+			bFound = true;
 		}
 		start = 0;
 		while (-1 != (start = ls->Get()->prefix.find(s_old, start))) {
 			ls->Get()->prefix.replace(start, len, s_new);
 			start += new_len;
-			found = 1;
+			bFound = true;
 		}
 
-		int ek_found = 0;
+		bool bKeyFound = false;
 		QString s;
 		if (edit_key) {
 			s = edit_key;
@@ -590,27 +590,27 @@ void DlgEqu::replaceString()
 			while (-1 != (start = s.find(s_old, start))) {
 				s.replace(start, len, s_new);
 				start += new_len;
-				ek_found = 1;
+				bKeyFound = true;
 			}
-			if (ek_found) {
+			if (bKeyFound) {
 				free(edit_key);
 				edit_key = strdup((char *)(const char *)s);
-				found = 1;
+				bFound = true;
 			}
 		}
-		ek_found = 0;
+		bKeyFound = false;
 		s = ls->getText();
 		start = 0;
 		while (-1 != (start = s.find(s_old, start))) {
 			s.replace(start, len, s_new);
 			start += new_len;
-			ek_found = 1;
+			bKeyFound = true;
 		}
-		if (ek_found) ls->setText(s);
+		if (bKeyFound) ls->setText(s);
 
 		ls = ls->Next();
 	}
-	if (found) fillList();
+	if (bFound) fillList();
 }
 
 void DlgEqu::clearSelection()
@@ -694,20 +694,33 @@ void DlgEqu::deleteEquation()
 	}
 }
 
-// retrieve the list of equations; either from the XDeviceNet or from the XDevice
+// retrieve the list of equations; either from the Circuit or from the XDevice
 void DlgEqu::parseCircuit()
 {
 	freemem();
 
 	deleted_equations = new KlogicList<OutputInfo>;
 
+	// optimize ! ! !
 	if (net) {
-		equations = net->parseCircuit();
+		equations = new KlogicList<OutputInfo>;
+		map<QString, OutputInfo> oEquations;
+		net->getAllEquations(oEquations, "", false);
+		for (map<QString,OutputInfo>::iterator iter = oEquations.begin(); iter != oEquations.end(); iter++) {
+			OutputInfo *oi = new OutputInfo(iter->second);
+			
+			equations->Append(oi)->setText(iter->first);
+		}
 	}
 
 	if (dev) {
 		equations = new KlogicList<OutputInfo>;
-		dev->getAllEquations(equations, (char *)NULL, Device::NO_QUALS);
+		map<QString,OutputInfo> oEquations;
+		dev->getAllEquations(oEquations, "", true);
+		for (map<QString,OutputInfo>::iterator iter = oEquations.begin(); iter != oEquations.end(); iter++) {
+			OutputInfo *oi = new OutputInfo(iter->second);
+			equations->Append(oi)->setText(iter->first);
+		}
 	}
 
 	fillList();
@@ -721,7 +734,7 @@ void DlgEqu::parseCircuit()
 // normalize all equations
 void DlgEqu::normalizeEquations()
 {	KlogicList<OutputInfo> *ls = equations->First();
-	SymbolOpStack opp;
+	SymbolicCalc opp;
 
 	// build result table
 	while(ls) {
@@ -761,14 +774,10 @@ void DlgEqu::collectEquations()
 
 int DlgEqu::substituteEquations()
 {	KlogicList<OutputInfo> *ls1;				// all equations
-	SymbolOpStack nt;					// equation-parser
-	SymbolOpStack opt;					// equation-optimizer
 	KlogicList<OutputInfo> *ls2;				// equation to substitute with
 	KlogicList<QString> substituted;			// list of substituted non-terminal
 	QString dummy;					// dummy entry for substituted - list
-	int found;					// device equation changed
 	int changed;					// circuit equations changed
-	int i, j;
 	int iplane;
 	int plane = Device::TMP_OUTPUT;
 
@@ -790,72 +799,74 @@ int DlgEqu::substituteEquations()
 				// initialize list of already substituted non-terminal
 				substituted.Destroy();
 
+				bool bFound;
 				do {
-					found = 0;
+					bFound = false;
 
 					// create a calculation queue with all names of the current equation in it
-					nt.setEquation(ls1->Get()->equation);
-					nt.parse();
-
-					// nterns contains all names ...
-					char **nterms = nt.getQueue();
-					int cnt = nt.getCounter();
-
-					// nterm_info contains the position of a name within its equation
-					QueueInfo **nterm_info = nt.getInfo();
+					SymbolicCalc oSymCalc;
+					oSymCalc.setEquation(ls1->Get()->equation);
+					oSymCalc.parse();
+					CalcRules& oCalcRules = oSymCalc.getCalcRules();
 
 					// search equation for each name, then substitute it
 					// (the name could also be an operator: ignored)
-					for (i = 0; i < cnt; i++) {
-						// substitute non-terminals /outputs with their terminals /equations
-						if (NULL != (ls2 = equations->With(nterms[i]))) {
+					for (int i = 0; i < oCalcRules.size(); i++) {
+						if (Operator::isOP(oCalcRules.getOperator(i)))
+							continue;
+
+						// substitute name with its equation
+						if (NULL != (ls2 = equations->With(oCalcRules.getItem(i)))) {
+							int iOutputType = 0;
 							// already marked as internal output?
 							if (ls2->Get()->output_type == Device::INTERNAL_OUTPUT) {
-								nterm_info[i]->type = Device::INTERNAL_OUTPUT;
+								iOutputType = Device::INTERNAL_OUTPUT;
 							}
 
 							// ls1 and ls2 are the same equation?
 							// already subsituted? there is a loop, mark as internal output
-							if (nterm_info[i]->type != Device::INTERNAL_OUTPUT && (ls1 == ls2 || substituted.With(nterms[i]))) {
-								nterm_info[i]->type = Device::INTERNAL_OUTPUT;
+							if (iOutputType != Device::INTERNAL_OUTPUT && (ls1 == ls2 || substituted.With(oCalcRules.getItem(i)))) {
 								ls2->Get()->output_type = Device::INTERNAL_OUTPUT;
+								iOutputType = Device::INTERNAL_OUTPUT;
 							}
 
 							// substitute..
-							if (nterm_info[i]->type != Device::INTERNAL_OUTPUT) {
-								QString s = ls1->Get()->equation.left(nterm_info[i]->position);
+							if (iOutputType != Device::INTERNAL_OUTPUT) {
+								QString s = ls1->Get()->equation.left(oCalcRules[i].m_iPos);
 								s += "(";
 								s += ls2->Get()->equation;
 								s += ")";
-								s += ls1->Get()->equation.right(ls1->Get()->equation.length() - nterm_info[i]->position - nterm_info[i]->length);
+								s += ls1->Get()->equation.right(ls1->Get()->equation.length() - oCalcRules[i].m_iPos - oCalcRules[i].m_iLen);
 
 								// correct the positions..
-								for (j=0; j < cnt; j++)
-									if (nterm_info[j]->position > nterm_info[i]->position)
-										nterm_info[j]->position += s.length() - ls1->Get()->equation.length();
+								for (int j = 0; j < oCalcRules.size(); j++)
+									if (oCalcRules[j].m_iPos > oCalcRules[i].m_iPos)
+										oCalcRules[j].m_iPos += s.length() - ls1->Get()->equation.length();
 
 								// replace the equation with the substituted one
 								ls1->Get()->equation = s;
 
 								// substitute again
 								changed = 1;
-								found = 1;
+								bFound = true;
 							}
 						}
 					}
 
-					// remember all substituted non-terminals
-					for(i = 0; i < cnt; i++) {
-						if (!substituted.With(nterms[i]))
-							substituted.Append(&dummy)->setText(nterms[i]);
+					// remember all substituted
+					for(int i = 0; i < oCalcRules.size(); i++) {
+						if (Operator::isOP(oCalcRules.getOperator(i)))
+							continue;
+						if (!substituted.With(oCalcRules.getItem(i)))
+							substituted.Append(&dummy)->setText(oCalcRules.getItem(i));
 					}
-				} while(found);
+				} while(bFound);
 
 				// ls1 is substituted now. optimize the newly generated equation
-				opt.setEquation(ls1->Get()->equation);
-				opt.parse();
-				QString s = opt.calculateSymbolic();
-				ls1->Get()->equation = s;
+				SymbolicCalc oOptCalc;
+				oOptCalc.setEquation(ls1->Get()->equation);
+				oOptCalc.parse();
+				ls1->Get()->equation = oOptCalc.calculateSymbolic();
 			} // if (plane)
 
 			// retrieve the next equation
