@@ -17,20 +17,6 @@
 #define NOACTIVE	"no active node!"
 #define NOACTIVECONN	"connectInput: no active node or node not end-node!"
 
-// string delimiter (io operations): ctrl-A
-#define DLM		1
-
-// screen definitions
-#define SCREEN_SIZE_X		800
-#define SCREEN_SIZE_Y		600
-
-#define VIRT_SCREEN_SIZE_X	1600
-#define VIRT_SCREEN_SIZE_Y	1200
-
-#define GRID		10
-#define GRIDHALF	5
-#define GRIDDOUBLE	20
-
 // default font definition
 #define FONTTYPE	"adobe-courier"
 #define FONTSIZE	8
@@ -41,8 +27,37 @@
 #include <qstring.h>
 #include <klocale.h>
 
-extern QString myAppName;
-extern QString emptyFileName;
+namespace Global
+{
+	class Klogic
+	{
+	public:
+		static const QString Name;
+		static const QString emptyFileName;
+	};
+
+	class Screen
+	{
+	public:
+		static const int SCREEN_SIZE_X = 800;
+		static const int SCREEN_SIZE_Y = 600;
+
+		static int VIRT_SCREEN_SIZE_X;
+		static int VIRT_SCREEN_SIZE_Y;
+	};
+
+	class CurrentCircuit
+	{
+	public:
+		static QString filename;
+		static QString version;
+		static QString creation;
+		static QString author;
+		static QString title;
+		static QString comment;
+	};
+
+};
 
 class uniqueID
 {
@@ -53,15 +68,4 @@ private:
 	static int id;
 };
 
-class CurrentCircuit
-{
-public:
-	static QString filename;
-	static QString version;
-	static QString creation;
-	static QString author;
-	static QString title;
-	static QString comment;
-};
-
 #endif
