@@ -14,6 +14,7 @@
 #include <kmenubar.h>
 #include <kpopupmenu.h>
 
+#include <qwidgetfactory.h>
 #include <qpainter.h>
 #include <qkeycode.h>
 #include <qprinter.h>
@@ -24,9 +25,9 @@
 #include <qslider.h>
 #include <qcombobox.h>
 
+#include "xwire.h"
 #include "mainw.h"
 #include "netw.h"
-#include "xwire.h"
 #include "klogic.h"
 #include "klogicIO.h"
 #include "version.h"
@@ -47,8 +48,6 @@ QString MainWidget::PATH;
 QString MainWidget::TBPATH;
 int MainWidget::mode = MAIN_MODE_DRAW;
 DevLibrary * MainWidget::activeLib = (DevLibrary *)NULL;
-QString myAppName = "klogic";
-QString emptyFileName = i18n("new.circuit");
 
 // private static
 void MainWidget::setPATH(KApplication *app)
@@ -58,12 +57,11 @@ void MainWidget::setPATH(KApplication *app)
 
 	if (!klogic_path.isNull()) {
 		// path comes from environment
-		fprintf(stderr, "\nlocal path set to <%s>\n", (const char *)klogic_path);
 		warning("using local directories: [remove KLOGIC_PATH] try \"make install\"");
 		PATH = klogic_path + "/pics/";
 		TBPATH = klogic_path + "/toolbar/";
 		if (FALSE == pix.load(PATH + "AND.xpm"))
-			fatal("***** aborting ***** : cannot find my icons ... (invalid $KLOGIC_PATH)");
+			fatal("***** aborting ***** : you should install klogic with 'make install` - or set $KLOGIC_PATH");
 	} else {
 		// path comes from kde
 		bool found = false;
@@ -90,8 +88,8 @@ MainWidget::MainWidget(KApplication *_app, const char *file)
 	setPATH(app);
 
 	setBackgroundMode( PaletteBase );    // set widgets background
-	resize(SCREEN_SIZE_X, SCREEN_SIZE_Y);                  // set default size in pixels
-	setPlainCaption(myAppName + " - " + emptyFileName);
+	resize(Global::Screen::SCREEN_SIZE_X, Global::Screen::SCREEN_SIZE_Y);                  // set default size in pixels
+	setPlainCaption(Global::Klogic::Name + " - " + Global::Klogic::emptyFileName);
 
 	// read config
 	readProperties(app->config());
@@ -105,15 +103,15 @@ MainWidget::MainWidget(KApplication *_app, const char *file)
 	if (!(main_netwidget = client_widget->net())) fatal("unable to create inital circuit..\n");
 
 	if (file) {
-		CurrentCircuit::filename = file;
-		QFileInfo fi(CurrentCircuit::filename);
-		setPlainCaption(myAppName + " - " + fi.fileName());
+		Global::CurrentCircuit::filename = file;
+		QFileInfo fi(Global::CurrentCircuit::filename);
+		setPlainCaption(Global::Klogic::Name + " - " + fi.fileName());
 	}
 
 	client_widget->show();
 	connect(main_netwidget, SIGNAL(netChanged(int)), this, SLOT(netChange(int)));
-	connect(main_netwidget, SIGNAL(createNewWidget(XDeviceNet *)), this, SLOT(newClient(XDeviceNet *)));
-	connect(main_netwidget, SIGNAL(netDeleted(XDeviceNet *)), this, SLOT(netDelete(XDeviceNet *)));
+	connect(main_netwidget, SIGNAL(createNewWidget(Circuit *)), this, SLOT(newClient(Circuit *)));
+	connect(main_netwidget, SIGNAL(netDeleted(Circuit *)), this, SLOT(netDelete(Circuit *)));
 	connect(main_netwidget, SIGNAL(netChanged(int)), client_widget, SLOT(netChange(int)));
 
 	initToolbar();
@@ -122,14 +120,14 @@ MainWidget::MainWidget(KApplication *_app, const char *file)
 	initMenubar();
 	setCentralWidget(client_widget);
 
-	scrollSimW = new ScrollableSimw(myAppName + " - " + i18n("oscillograph"));
+	scrollSimW = new ScrollableSimw(Global::Klogic::Name + " - " + i18n("oscillograph"));
 	simW = new SimW(scrollSimW->getClientParent(), scrollSimW, main_netwidget->getActive());
 	scrollSimW->setClient(simW);
 	connect(scrollSimW, SIGNAL(simWidgetGoesHidden()), this, SLOT(simWidgetHidden()));
 
 	connect(main_netwidget, SIGNAL(graphChanged()), simW, SLOT(graphChange()));
 	connect(main_netwidget, SIGNAL(simStepped()), simW, SLOT(simStep()));
-	connect(main_netwidget, SIGNAL(showGraph(XDeviceNet *)), simW, SLOT(changeNet(XDeviceNet *)));
+	connect(main_netwidget, SIGNAL(showGraph(Circuit *)), simW, SLOT(changeNet(Circuit *)));
 	connect(main_netwidget, SIGNAL(addToLib(XDevice *)), this, SLOT(addToLib(XDevice *)));
 	simW->setSimMode(main_netwidget->getSimMode());
 	scrollSimW->hide();
@@ -568,42 +566,42 @@ void MainWidget::menuCallback(int id)
 			devChange(id);
 			break;
 		case ID_OPEN:
-			fi.setFile(CurrentCircuit::filename);
+			fi.setFile(Global::CurrentCircuit::filename);
 			new_filename = KFileDialog::getOpenFileName(fi.dirPath(), "*.circuit");
 			if (!new_filename.isEmpty()) {
 				closeAllClients();
 				i = main_netwidget->openNet(new_filename, circuit_changed);
 				if (i > 0) {
-					CurrentCircuit::filename = new_filename;
+					Global::CurrentCircuit::filename = new_filename;
 					if (i == 1) {	// not a subcircuit
-						fi.setFile(CurrentCircuit::filename);
-						setPlainCaption(myAppName + " - " + fi.fileName());
+						fi.setFile(Global::CurrentCircuit::filename);
+						setPlainCaption(Global::Klogic::Name + " - " + fi.fileName());
 					}
 				} else {
-					CurrentCircuit::filename = new_filename;
-					fi.setFile(CurrentCircuit::filename);
-					setPlainCaption(myAppName + " - " + fi.fileName());
+					Global::CurrentCircuit::filename = new_filename;
+					fi.setFile(Global::CurrentCircuit::filename);
+					setPlainCaption(Global::Klogic::Name + " - " + fi.fileName());
 				}
 			}
 			break;
 		case ID_SAVE:
 			// save-command: always save toplevel circuit!
-			fi.setFile(CurrentCircuit::filename);
+			fi.setFile(Global::CurrentCircuit::filename);
 			if (fi.exists()) {
-				main_netwidget->saveNet(CurrentCircuit::filename, false);
-				setPlainCaption(myAppName + " - " + fi.fileName());
+				main_netwidget->saveNet(Global::CurrentCircuit::filename, false);
+				setPlainCaption(Global::Klogic::Name + " - " + fi.fileName());
 			} else menuCallback(ID_SAVE_AS);
 			break;
 		case ID_SAVE_AS:
 			// save-as-command: ask for saving sub circuit
 			save_as_sub = main_netwidget->saveAsSubNet();
-			fi.setFile(CurrentCircuit::filename);
+			fi.setFile(Global::CurrentCircuit::filename);
 			new_filename = KFileDialog::getSaveFileName(fi.dirPath(), "*.circuit");
 			if (!new_filename.isEmpty()) {
 				main_netwidget->saveNet(new_filename, save_as_sub);
-				CurrentCircuit::filename = new_filename;
-				fi.setFile(CurrentCircuit::filename);
-				setPlainCaption(myAppName + " - " + fi.fileName());
+				Global::CurrentCircuit::filename = new_filename;
+				fi.setFile(Global::CurrentCircuit::filename);
+				setPlainCaption(Global::Klogic::Name + " - " + fi.fileName());
 			}
 			break;
 		case ID_PRINT:
@@ -616,9 +614,9 @@ void MainWidget::menuCallback(int id)
 		case ID_NEW:
 			closeAllClients();
 			main_netwidget->newNet();
-			fi.setFile(CurrentCircuit::filename);
-			CurrentCircuit::filename = fi.dirPath() + "/" + emptyFileName;
-			setPlainCaption(myAppName + " - " + emptyFileName);
+			fi.setFile(Global::CurrentCircuit::filename);
+			Global::CurrentCircuit::filename = fi.dirPath() + "/" + Global::Klogic::emptyFileName;
+			setPlainCaption(Global::Klogic::Name + " - " + Global::Klogic::emptyFileName);
 			break;
 		case ID_EXIT:
 			if (queryClose())
@@ -684,11 +682,11 @@ void MainWidget::menuCallback(int id)
 		case ID_MAINTENANCE:
 			fprintf(stdout, "              INSTANCES\n");
 			fprintf(stdout, "-----------------------------------------\n");
-			fprintf(stdout, "XDeviceNet:\t%d\n", XDeviceNet::instance);
+			fprintf(stdout, "Circuit:\t%d\n", Circuit::instance);
 			fprintf(stdout, "-----------------------------------------\n");
 			fprintf(stdout, "XDevice:\t%d\n", XDevice::instance);
 			fprintf(stdout, "Device:\t\t%d\n", Device::instance);
-			fprintf(stdout, "opStack:\t%d\n", opStack::instance);
+			fprintf(stdout, "Calculator:\t%d\n", Calculator::instance);
 			fprintf(stdout, "Fifo:\t\t%d\n", Fifo::instance);
 			fprintf(stdout, "XWire:\t\t%d\n", XWire::instance);
 			fprintf(stdout, "-----------------------------------------\n");
@@ -753,7 +751,16 @@ void MainWidget::turnAllCheckButton(int id)
 }
 
 void MainWidget::dialogGlobal()
-{	int ret;
+{
+/*
+	QDialog *oGlobalPropertiesDlg = (QDialog *)
+            QWidgetFactory::create( "global_settings.ui" );
+
+	oGlobalPropertiesDlg->exec();
+	delete oGlobalPropertiesDlg;
+}
+*/
+	int ret;
 
 	PropGlob *dlg = new PropGlob(this, i18n("global settings"), main_netwidget);
 	dlg->move(pos().x() + 50, pos().y() + 50);
@@ -816,6 +823,12 @@ void MainWidget::dialogLibrary(XDevice *new_dev)
 void MainWidget::readProperties(KConfig *config)
 {	int ret;
 
+	config->setGroup("global");
+	ret = config->readNumEntry("virt_resolution_x", Global::Screen::VIRT_SCREEN_SIZE_X);
+	Global::Screen::VIRT_SCREEN_SIZE_X = ret;
+	ret = config->readNumEntry("virt_resolution_y", Global::Screen::VIRT_SCREEN_SIZE_Y);
+	Global::Screen::VIRT_SCREEN_SIZE_Y = ret;
+
 	config->setGroup("device");
 	ret = config->readNumEntry("size", XDevice::defSize());
 	XDevice::setDefSize(ret);
@@ -827,8 +840,8 @@ void MainWidget::readProperties(KConfig *config)
 	Device::setDefUndefined(ret);
 	ret = config->readNumEntry("invert", XDevice::isDefInverted());
 	XDevice::setDefInverted(ret);
-	ret = config->readNumEntry("nameDisplayed", XDevice::textDisplayedGlobal());
-	XDevice::displayTextGlobal(ret);
+	ret = config->readNumEntry("nameDisplayed", XDevice::nameDisplayedGlobal());
+	XDevice::displayNameGlobal(ret);
 	QString fnt = config->readEntry("device_font", XDevice::getFont());
 	XDevice::setFont(fnt);
 	ret = config->readNumEntry("device_font_size", XDevice::getFontSize());
@@ -859,7 +872,7 @@ void MainWidget::saveProperties(KConfig *config)
 	config->writeEntry("delay", Device::defDelay());
 	config->writeEntry("undefined", Device::defUndefined());
 	config->writeEntry("invert", XDevice::isDefInverted());
-	config->writeEntry("nameDisplayed", XDevice::textDisplayedGlobal());
+	config->writeEntry("nameDisplayed", XDevice::nameDisplayedGlobal());
 	config->writeEntry("device_font", XDevice::getFont());
 	config->writeEntry("device_font_size", XDevice::getFontSize());
 	config->writeEntry("device_symbolset", XDevice::getSymbolSet());
@@ -1046,21 +1059,14 @@ void MainWidget::addToLib(XDevice *new_dev)
 // find active window, redraw it and all client widgets with the same content
 void MainWidget::repaintClients()
 {	NetWidget *activeNetWidget = getActive();
-	XDeviceNet *activeDeviceNet;
-	NetWidget *netw;
 
-	if (activeNetWidget) {
-		activeDeviceNet = activeNetWidget->getActive();
-
-		// find inactive widgets containing the same net
-		KlogicList<ClientW> *lc = client_widgets.First();
-		while(lc) {
-			netw = lc->Get()->net();
-			//if (activeNetWidget != netw && activeDeviceNet == netw->getActive())
-			if (activeNetWidget != netw)
-				netw->repaint(FALSE);
-			lc = lc->Next();
-		}
+	// find inactive widgets containing the same net
+	KlogicList<ClientW> *lc = client_widgets.First();
+	while(lc) {
+		NetWidget *netw = lc->Get()->net();
+		if (activeNetWidget != netw)
+			netw->repaint(TRUE);
+		lc = lc->Next();
 	}
 	circuit_changed = true;
 }
@@ -1068,7 +1074,7 @@ void MainWidget::repaintClients()
 // slot: signal that all changes are saved
 void MainWidget::circuitUnchanged()
 {	NetWidget *activeNetWidget = getActive();
-	XDeviceNet *activeDeviceNet;
+	Circuit *activeDeviceNet;
 	NetWidget *netw;
 	KlogicList<ClientW> *lc;
 
@@ -1109,7 +1115,7 @@ NetWidget * MainWidget::getActive()
 
 // slot
 // sub circuit deleted
-void MainWidget::netDelete(XDeviceNet *delnet)
+void MainWidget::netDelete(Circuit *delnet)
 {
 	NetWidget *oldnet;
 	ClientW *old_client_widget;
@@ -1134,15 +1140,15 @@ void MainWidget::netDelete(XDeviceNet *delnet)
 
 // slot
 // display circuit in a new window
-void MainWidget::newClient(XDeviceNet *devnet)
+void MainWidget::newClient(Circuit *devnet)
 {	NetWidget *newnet;
 
 	ClientW *client_widget = new ClientW(this, devnet);
 	client_widgets.Append(client_widget);
 
 	newnet = client_widget->net();
-	connect(newnet, SIGNAL(createNewWidget(XDeviceNet *)), this, SLOT(newClient(XDeviceNet *)));
-	connect(newnet, SIGNAL(netDeleted(XDeviceNet *)), this, SLOT(netDelete(XDeviceNet *)));
+	connect(newnet, SIGNAL(createNewWidget(Circuit *)), this, SLOT(newClient(Circuit *)));
+	connect(newnet, SIGNAL(netDeleted(Circuit *)), this, SLOT(netDelete(Circuit *)));
 	// NetWidget reports to clientw and this
 	connect(newnet, SIGNAL(netChanged(int)), client_widget, SLOT(netChange(int)));
 	connect(newnet, SIGNAL(netChanged(int)), this, SLOT(netChange(int)));
@@ -1150,7 +1156,7 @@ void MainWidget::newClient(XDeviceNet *devnet)
 	// device deleted which was shown in the simulation graph
 	connect(newnet, SIGNAL(graphChanged()), simW, SLOT(graphChange()));
 	// NetWidget shown in simulation graph has changed
-	connect(newnet, SIGNAL(showGraph(XDeviceNet *)), simW, SLOT(changeNet(XDeviceNet *)));
+	connect(newnet, SIGNAL(showGraph(Circuit *)), simW, SLOT(changeNet(Circuit *)));
 	// NetWidget add library device
 	connect(newnet, SIGNAL(addToLib(XDevice *)), this, SLOT(addToLib(XDevice *)));
 	// perform a simulation stepin the simulation graph
@@ -1184,13 +1190,13 @@ void MainWidget::closeClient(ClientW *client_widget)
 	if (lc && lc->Get()) {
 		lc->Destroy(client_widget);
 		oldnet = client_widget->net();
-		disconnect(oldnet, SIGNAL(createNewWidget(XDeviceNet *)), this, SLOT(newClient(XDeviceNet *)));
-		disconnect(oldnet, SIGNAL(netDeleted(XDeviceNet *)), this, SLOT(netDelete(XDeviceNet *)));
+		disconnect(oldnet, SIGNAL(createNewWidget(Circuit *)), this, SLOT(newClient(Circuit *)));
+		disconnect(oldnet, SIGNAL(netDeleted(Circuit *)), this, SLOT(netDelete(Circuit *)));
 		disconnect(oldnet, SIGNAL(netChanged(int)), client_widget, SLOT(netChange(int)));
 		disconnect(oldnet, SIGNAL(netChanged(int)), this, SLOT(netChange(int)));
 		// signals for the widget showing simulation graphs
 		disconnect(oldnet, SIGNAL(graphChanged()), simW, SLOT(graphChange()));
-		disconnect(oldnet, SIGNAL(showGraph(XDeviceNet *)), simW, SLOT(changeNet(XDeviceNet *)));
+		disconnect(oldnet, SIGNAL(showGraph(Circuit *)), simW, SLOT(changeNet(Circuit *)));
 		disconnect(oldnet, SIGNAL(addToLib(XDevice *)), this, SLOT(addToLib(XDevice *)));
 		disconnect(oldnet, SIGNAL(simStepped()), simW, SLOT(simStep()));
 		netChange(0);
