@@ -30,7 +30,7 @@
 #include "netw.h"
 #include "klogic.h"
 #include "klogicIO.h"
-#include "xnet.h"
+#include "circuit.h"
 #include "xdevice.h"
 #include "deviceTypes.h" 
 #include "selection.h"
@@ -42,6 +42,7 @@
 #include "propSwitch.h"
 #include "dlgEqu.h"
 #include "xmlImport.h"
+#include "grid.h"
 
 #include "netw.moc"
 //********************************************
@@ -123,13 +124,13 @@ NetWidget::NetWidget(QWidget *hparent, QWidget *parent) : QFrame(hparent)
 	setBackgroundMode(PaletteBase);    // set widgets background
 	setBackgroundColor(white);
 	setFrameStyle( QFrame::Panel | QFrame::Raised );
-	resize(VIRT_SCREEN_SIZE_X, VIRT_SCREEN_SIZE_Y);                  // set default size in pixels
+	resize(Global::Screen::VIRT_SCREEN_SIZE_X, Global::Screen::VIRT_SCREEN_SIZE_Y);                  // set default size in pixels
 
-	activeNet = new XDeviceNet();
+	activeNet = new Circuit();
 	activeDev = (XDevice *)NULL;
 	activeWire = (XWire *)NULL;
 	activeSelection = new Selection();
-	_parent = parent;
+	m_oParent = parent;
 
 	// drawing mode
 	setSimMode(NetWidget::MODE_SIM_MULT);
@@ -148,8 +149,8 @@ NetWidget::NetWidget(QWidget *hparent, QWidget *parent) : QFrame(hparent)
 	connect(rselpop, SIGNAL (activated (int)), SLOT (rmenuSelCallback(int)));
 
 	changed = false;
-	movecursor = 0;
-	rmenuActive = 0;
+	m_bSelMoveCursor = false;
+	m_bRMenuActive = false;
 
 	runtimeShortcutWarning = true;
 
@@ -159,7 +160,7 @@ NetWidget::NetWidget(QWidget *hparent, QWidget *parent) : QFrame(hparent)
 	connect(this, SIGNAL(netContentUnchanged()), parent, SLOT(circuitUnchanged()));
 }
 
-NetWidget::NetWidget(QWidget *hparent, QWidget *parent, XDeviceNet *net)
+NetWidget::NetWidget(QWidget *hparent, QWidget *parent, Circuit *net)
 	: QFrame(hparent)
 {
 	client = true;
@@ -167,13 +168,13 @@ NetWidget::NetWidget(QWidget *hparent, QWidget *parent, XDeviceNet *net)
 	setBackgroundMode(PaletteBase);    // set widgets background
 	setBackgroundColor(white);
 	setFrameStyle( QFrame::Panel | QFrame::Raised );
-	resize(VIRT_SCREEN_SIZE_X, VIRT_SCREEN_SIZE_Y);                // set default size in pixels
+	resize(Global::Screen::VIRT_SCREEN_SIZE_X, Global::Screen::VIRT_SCREEN_SIZE_Y);                // set default size in pixels
 
 	activeNet = net;
 	activeDev = (XDevice *)NULL;
 	activeWire = (XWire *)NULL;
 	activeSelection = new Selection();
-	_parent = hparent;
+	m_oParent = hparent;
 
 	// device to drop when in drop-mode
 	actualDevFunc = 0;
@@ -190,8 +191,8 @@ NetWidget::NetWidget(QWidget *hparent, QWidget *parent, XDeviceNet *net)
 	connect(rselpop, SIGNAL (activated (int)), SLOT (rmenuSelCallback(int)));
 
 	changed = false;
-	movecursor = 0;
-	rmenuActive = 0;
+	m_bSelMoveCursor = false;
+	m_bRMenuActive = false;
 
 	runtimeShortcutWarning = true;
 
@@ -213,8 +214,8 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 {	QPainter p;
 
 	if (e->button() == LeftButton) {
-		if (rmenuActive) {
-			rmenuActive = 0;
+		if (m_bRMenuActive) {
+			m_bRMenuActive = false;
 			return;
 		}
 
@@ -226,7 +227,7 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 				activeDev->setOrigin();
 
 				// if device is a push button device,  toggle its status
-				if (activeDev->isInteractive() && !activeDev->isSwitchType()) {
+				if (activeDev->isInteractive() && activeDev->isToggle()) {
 					activeDev->toggleStaticInput();
 					p.begin(this);
 					activeNet->drawAll(this, &p);
@@ -258,7 +259,7 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 				activeDev->setOrigin();
 
 				// if device is a push button device,  toggle its status
-				if (activeDev->isInteractive() && !activeDev->isSwitchType()) {
+				if (activeDev->isInteractive() && activeDev->isToggle()) {
 					activeDev->toggleStaticInput();
 					p.begin(this);
 					activeNet->drawAll(this, &p);
@@ -277,19 +278,19 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 			// create new device
 			activeDev = activeNet->newDevice(actualDevFunc, e->pos().x(), e->pos().y());
 			if (!activeDev && (actualDevFunc == DeviceType::fIN)) {
-				QMessageBox::warning(_parent, i18n("device failure"), i18n("unable to add more named inputs\nresize this sub circuit"));
+				QMessageBox::warning(m_oParent, i18n("device failure"), i18n("unable to add more named inputs\nresize this sub circuit"));
 				emit netContentChanged();
 				changed = true;
 				return;
 			}
 			if (!activeDev && (actualDevFunc == DeviceType::fOUT)) {
-				QMessageBox::warning(_parent, i18n("device failure"), i18n("unable to add more named outputs\nresize this sub circuit"));
+				QMessageBox::warning(m_oParent, i18n("device failure"), i18n("unable to add more named outputs\nresize this sub circuit"));
 				emit netContentChanged();
 				changed = true;
 				return;
 			}
 			if (!activeDev) {
-				QMessageBox::warning(_parent, i18n("device failure"), i18n("panic: cannot create device!"));
+				QMessageBox::warning(m_oParent, i18n("device failure"), i18n("panic: cannot create device!"));
 				return;
 			}
 			if (activeNet->containsDev(activeDev)) {
@@ -379,20 +380,20 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 		if (MainWidget::getMode() == MainWidget::MAIN_MODE_SELECT) {
 			activeSelection->at(e->pos());
 			selRightSelMenu(e);
-			rmenuActive = 1;
+			m_bRMenuActive = true;
 			return;
 		}
 
 		// device right clicked? open popup to chooce operation
 		if (NULL != (activeDev = activeNet->containsDev(e->pos()))) {
 			selRightMenu(e);
-			rmenuActive = 1;
+			m_bRMenuActive = true;
 			return;
 		}
 
 		// right clicked twice?
-		if (rmenuActive) {
-			rmenuActive = 0;
+		if (m_bRMenuActive) {
+			m_bRMenuActive = false;
 			return;
 		}
 
@@ -482,22 +483,22 @@ void NetWidget::mouseReleaseEvent( QMouseEvent *e)
 		ret = activeNet->checkConnection(activeWire);
 		switch (ret) {
 		case NFAIL:
-			QMessageBox::warning(_parent,
+			QMessageBox::warning(m_oParent,
 				i18n("connection failure"),
 				i18n("only one output per wire allowed"));
 			break;
 		case DFAILMAXI:
-			QMessageBox::warning(_parent,
+			QMessageBox::warning(m_oParent,
 				i18n("connection failure"),
 				i18n("maximum number of inputs exeeded"));
 			break;
 		case DFAILMAXO:
-			QMessageBox::warning(_parent,
+			QMessageBox::warning(m_oParent,
 				i18n("connection failure"),
 				i18n("maximum number of outputs exeeded"));
 			break;
 		case WSHORT:
-			QMessageBox::warning(_parent,
+			QMessageBox::warning(m_oParent,
 				i18n("connection failure"),
 				i18n("shortcut\n"));
 			break;
@@ -519,20 +520,22 @@ void NetWidget::mouseMoveEvent( QMouseEvent *e )
 {	QPainter p;
 
 	if (MainWidget::getMode() == MainWidget::MAIN_MODE_SELECT) {
-		if (FALSE == hasMouseTracking()) setMouseTracking(TRUE);
+		if (!hasMouseTracking())
+			setMouseTracking(true);
 		if (activeSelection->getStatus() == SEL_EXISTS && activeSelection->onFrame(e->pos())) {
-			if (!movecursor) {
-				movecursor = 1;
+			if (!m_bSelMoveCursor) {
+				m_bSelMoveCursor = true;
 				setCursor(sizeAllCursor);
 				return;
 			}
 		} else {
-			if (movecursor) {
-				movecursor = 0;
+			if (m_bSelMoveCursor) {					// switch selecion cursor
+				m_bSelMoveCursor = false;
 				setCursor(arrowCursor);
 				return;
 			}
-			if (activeSelection->getStatus() == SEL_START) {		// making frames
+			if (activeSelection->getStatus() == SEL_START) {	// make selections
+				emit(autoMove(e->pos()));	// move circuit when nessecary
 				activeSelection->changeFrame(e->pos());
 				p.begin(this);
 				activeSelection->erase(&p);
@@ -542,7 +545,8 @@ void NetWidget::mouseMoveEvent( QMouseEvent *e )
 				emit netContentChanged();
 				return;
 			}
-			if (activeSelection->getStatus() == SEL_MOVE) {		// moving frames
+			if (activeSelection->getStatus() == SEL_MOVE) {		// move selections
+				emit(autoMove(e->pos()));	// move circuit when nessecary
 				p.begin(this);
 				activeSelection->moveFrame(e->pos(), &p);
 				activeNet->drawAll(this, &p);
@@ -553,16 +557,21 @@ void NetWidget::mouseMoveEvent( QMouseEvent *e )
 		}
 		return;
 	}
-	if (TRUE == hasMouseTracking()) {
+
+	if (hasMouseTracking()) {
 		activeDev = (XDevice *)NULL;
 		activeWire = (XWire *)NULL;
-		setMouseTracking(FALSE);
+		m_bSelMoveCursor = false;
+		setCursor(arrowCursor);
+		setMouseTracking(false);
 	}
 
-	if (rmenuActive) return;
+	if (m_bRMenuActive) return;
 
 	// move wire/device
 	if (activeDev) {
+		emit(autoMove(e->pos()));	// move circuit when nessecary
+
 		if (activeDev->setPos(e->pos())) {
 			p.begin(this);
 			activeNet->drawDev(this, &p, activeDev);
@@ -571,6 +580,8 @@ void NetWidget::mouseMoveEvent( QMouseEvent *e )
 		}
 	}
 	if (activeWire) {
+		emit(autoMove(e->pos()));	// move if nessecary
+
 		p.begin(this);
 		activeWire->erase(&p);
 		activeWire->updateNode(e->pos());
@@ -610,17 +621,17 @@ void NetWidget::paintEvent(QPaintEvent *)
 	int x1s, y1s, x2s, y2s;
 	QPainter p;
 
-	x1s = visi.x() / GRID * GRID - GRID;
-	x2s = (visi.width() + visi.x()) / GRID * GRID + GRID;
-	y1s = visi.y() / GRID * GRID - GRID;
-	y2s = (visi.height() +  visi.y()) / GRID * GRID + GRID;
+	x1s = m_oVisibleRect.x() / Grid::GRID * Grid::GRID - Grid::GRID;
+	x2s = (m_oVisibleRect.width() + m_oVisibleRect.x()) / Grid::GRID * Grid::GRID + Grid::GRID;
+	y1s = m_oVisibleRect.y() / Grid::GRID * Grid::GRID - Grid::GRID;
+	y2s = (m_oVisibleRect.height() +  m_oVisibleRect.y()) / Grid::GRID * Grid::GRID + Grid::GRID;
 
 	if (!isActiveWindow()) erase();
 
 	p.begin(this);
 	p.setPen(black);
-	for(x = x1s ; x < x2s ;x += GRID)
-		for(y = y1s; y < y2s; y += GRID)
+	for(x = x1s ; x < x2s ;x += Grid::GRID)
+		for(y = y1s; y < y2s; y += Grid::GRID)
 			p.drawPoint(x, y);
 	activeNet->drawAll(this, &p);
 	activeSelection->draw(&p);
@@ -692,8 +703,8 @@ void NetWidget::rmenuCallback(int val)
 			emit graphChanged();
 			break;
 		case RPOP_SHOWGRAPH:
-			if (activeDev->devIsNet())
-				emit showGraph(activeDev->devIsNet());
+			if (activeDev->devIsCircuit())
+				emit showGraph(activeDev->devIsCircuit());
 			break;
 		case RPOP_ADD_LIB:
 			// send signal to main widget
@@ -703,7 +714,7 @@ void NetWidget::rmenuCallback(int val)
 		default:
 			break;
 	}
-	rmenuActive = 0;
+	m_bRMenuActive = false;
 }
 
 // right mouse button popup entries on selections
@@ -747,7 +758,7 @@ void NetWidget::rmenuSelCallback(int val)
 		default:
 			break;
 	}
-	rmenuActive = 0;
+	m_bRMenuActive = false;
 }
 
 // remove old selections
@@ -769,7 +780,7 @@ void NetWidget::deleteDev(int ask)
 
 	if (activeDev->type() == DeviceType::fNET) {
 		if (ask) {
-			if (1 == QMessageBox::warning(_parent, i18n("remove device"),
+			if (1 == QMessageBox::warning(m_oParent, i18n("remove device"),
 					i18n("remove entire sub-circuit?"), i18n("OK"), i18n("Cancel")))
 			{
 				activeDev = (XDevice *)NULL;
@@ -777,7 +788,7 @@ void NetWidget::deleteDev(int ask)
 			}
 		}
 		emit netContentChanged();
-		emit netDeleted(activeDev->devIsNet());
+		emit netDeleted(activeDev->devIsCircuit());
 	}
 	if (!activeDev->drawGraph() ||  !activeDev->graphEnabled())
 		simw_rel = 0;
@@ -797,7 +808,7 @@ int NetWidget::openProp()
 
 	// open properties for oszillators
 	if (activeDev->type() == DeviceType::fOSC) {
-		PropOsz *dlg = new PropOsz(_parent, i18n("oscillator properties"), activeNet, activeDev);
+		PropOsz *dlg = new PropOsz(m_oParent, i18n("oscillator properties"), activeNet, activeDev);
 		if (simmode == MODE_SIM_MULT) simTimer.stop();
 		dlg->exec();
 		if (simmode == MODE_SIM_MULT) simTimer.start(STATsimStepTime);
@@ -811,7 +822,7 @@ int NetWidget::openProp()
 
 	// open properties for text devices
 	if (activeDev->type() == DeviceType::fTXT) {
-		PropText *dlg = new PropText(_parent, i18n("text label"), activeNet, activeDev);
+		PropText *dlg = new PropText(m_oParent, i18n("text label"), activeNet, activeDev);
 		dlg->exec();
 		delete dlg;
 		activeDev = (XDevice *)NULL;
@@ -822,7 +833,7 @@ int NetWidget::openProp()
 
 	// open properties for power sources
 	if (activeDev->type() == DeviceType::fPWR) {
-		PropPwr *dlg = new PropPwr(_parent, i18n("power device properties"), activeNet, activeDev);
+		PropPwr *dlg = new PropPwr(m_oParent, i18n("power device properties"), activeNet, activeDev);
 		dlg->exec();
 		delete dlg;
 		p.begin(this);
@@ -837,7 +848,7 @@ int NetWidget::openProp()
 
 	// open properties for switch devices
 	if (activeDev->type() == DeviceType::fSWI) {
-		PropSwitch *dlg = new PropSwitch(_parent, i18n("switch device properties"), activeNet, activeDev);
+		PropSwitch *dlg = new PropSwitch(m_oParent, i18n("switch device properties"), activeNet, activeDev);
 		if (simmode == MODE_SIM_MULT) simTimer.stop();
 		dlg->exec();
 		if (simmode == MODE_SIM_MULT) simTimer.start(STATsimStepTime);
@@ -853,7 +864,7 @@ int NetWidget::openProp()
 	// open properties for inputs and ouputs
 	if ((activeDev->type() == DeviceType::fIN) ||
 	    (activeDev->type() == DeviceType::fOUT)) {
-		PropName *dlg = new PropName(_parent, i18n("interface device name"), this, activeNet, activeDev);
+		PropName *dlg = new PropName(m_oParent, i18n("interface device name"), this, activeNet, activeDev);
 		if (simmode == MODE_SIM_MULT) simTimer.stop();
 		dlg->exec();
 		if (simmode == MODE_SIM_MULT) simTimer.start(STATsimStepTime);
@@ -867,9 +878,8 @@ int NetWidget::openProp()
 	}
 
 	// open dialog with common device properties
-	PropDev *dlg = new PropDev(_parent, i18n("device properties"),this ,activeNet, activeDev);
+	PropDev *dlg = new PropDev(m_oParent, i18n("device properties"),this ,activeNet, activeDev);
 	if (simmode == MODE_SIM_MULT) simTimer.stop();
-	//dlg->show();
 	dlg->exec();
 	activeDev->forceOutputChange();
 	if (simmode == MODE_SIM_MULT) simTimer.start(STATsimStepTime);
@@ -884,11 +894,11 @@ int NetWidget::openProp()
 
 // switch to sub circuit in a new window?
 int NetWidget::toSubNetW()
-{	XDeviceNet *new_activeNet;
+{	Circuit *new_activeNet;
 
 	if (!activeDev) return 0;
 
-	new_activeNet = activeDev->devIsNet();
+	new_activeNet = activeDev->devIsCircuit();
 	if (new_activeNet) {
 		// remove the current selection before switching to a new circuit
 		removeSelection();
@@ -901,9 +911,9 @@ int NetWidget::toSubNetW()
 
 // switch to sub circuit?
 int NetWidget::toSubNet()
-{	XDeviceNet *new_activeNet;
+{	Circuit *new_activeNet;
 
-	new_activeNet = activeDev->devIsNet();
+	new_activeNet = activeDev->devIsCircuit();
 	if (new_activeNet) {
 		// remove the current selection before switching to a new circuit
 		removeSelection();
@@ -925,7 +935,7 @@ int NetWidget::toSubNet()
 
 // switch to parent of active net
 void NetWidget::toParentNet()
-{	XDeviceNet *new_activeNet;
+{	Circuit *new_activeNet;
 
 	// remove the current selection before switching to a new circuit
 	removeSelection();
@@ -948,11 +958,11 @@ void NetWidget::toParentNet()
 }
 
 bool NetWidget::saveAsSubNet()
-{	XDeviceNet *_net = activeNet->rootParent();
+{	Circuit *_net = activeNet->rootParent();
 
 	_net = activeNet->rootParent();
 	if (_net != activeNet) {	
-		int ret = QMessageBox::warning(_parent,
+		int ret = QMessageBox::warning(m_oParent,
 				i18n("save circuit"),
 				i18n("the current circuit is a sub circuit.\nsave it as a.."),
 				i18n("main circuit"),
@@ -963,7 +973,7 @@ bool NetWidget::saveAsSubNet()
 }
 
 int NetWidget::saveNet(QString filename, bool as_sub_net)
-{	XDeviceNet *net;
+{	Circuit *net;
 	int ret;
 
 	if (as_sub_net)
@@ -980,7 +990,7 @@ int NetWidget::saveNet(QString filename, bool as_sub_net)
 	ret = io.write(as_sub_net, false, 0, 0);
 
 	if (ret <= 0) {
-		QMessageBox::warning(_parent,
+		QMessageBox::warning(m_oParent,
 			i18n("save error"),
 			i18n("unable to write file"));
 		return 0;
@@ -996,7 +1006,7 @@ int NetWidget::saveNet(QString filename, bool as_sub_net)
 // 1: ok, normal circuit
 // 2: ok, subcircuit
 int NetWidget::openNet(QString filename, bool main_circuit_changed)
-{	XDeviceNet *_net;
+{	Circuit *_net;
 	klogicIO *_io;
 	QPainter p;
 	bool create_sub = false;
@@ -1020,7 +1030,7 @@ int NetWidget::openNet(QString filename, bool main_circuit_changed)
 		// replace main circuit: ask!
 		// -----------------------------------------
 		if (main_circuit_changed && !activeNet->rootParent()->empty()) {
-			if (QMessageBox::Yes != QMessageBox::warning(_parent,
+			if (QMessageBox::Yes != QMessageBox::warning(m_oParent,
 				i18n("new circuit"), 
 				i18n("delete current circuit?"), 
 				QMessageBox::Yes, 
@@ -1033,13 +1043,13 @@ int NetWidget::openNet(QString filename, bool main_circuit_changed)
 		activeWire = (XWire *)NULL;
 
 		p.begin(this);
-		activeNet->deleteNet(&p);
+		activeNet->deleteCircuit(&p);
 		p.end();
 		emit netContentUnchanged();
 		uniqueID::reset();
 		changed = false;
 	} else {
-		QMessageBox::warning(_parent,
+		QMessageBox::warning(m_oParent,
 			i18n("read error"),
 			i18n("unknown file format"));
 		return 0;
@@ -1070,11 +1080,11 @@ int NetWidget::openNet(QString filename, bool main_circuit_changed)
 	// -----------------------------------------
 	if (!result) {
 		if (XMLImportHandler::errorsOccured()) {
-			QMessageBox::warning(_parent,
+			QMessageBox::warning(m_oParent,
 				i18n("read error"),
 				(const char *)XMLImportHandler::getErrors());
 		} else {
-			QMessageBox::warning(_parent,
+			QMessageBox::warning(m_oParent,
 			i18n("read error"),
 			i18n("unable to read file"));
 		}
@@ -1120,13 +1130,13 @@ int NetWidget::newNet()
 {	QPainter p;
 
 	if ((changed && !activeNet->empty() &&
-			QMessageBox::Yes == (QMessageBox::warning(_parent,
+			QMessageBox::Yes == (QMessageBox::warning(m_oParent,
 			i18n("new circuit"), 
 			i18n("delete current circuit?"), 
 			QMessageBox::Yes,
 			QMessageBox::No))) || (!changed)) {
 		p.begin(this);
-		activeNet->deleteNet(&p);
+		activeNet->deleteCircuit(&p);
 		p.end();
 		repaint(TRUE);
 		emit netContentUnchanged();
@@ -1170,15 +1180,15 @@ void NetWidget::showDeviceEquations()
 	delete equation_dialog;
 }
 
-// retrieve the active XDeviceNet
-XDeviceNet *NetWidget::getActive()
+// retrieve the active Circuit
+Circuit *NetWidget::getActive()
 {
 	return activeNet;
 }
 
 // check if given net is this or a parent of this
-int NetWidget::contained(XDeviceNet *rootnet)
-{	XDeviceNet *_rootnet = activeNet;
+int NetWidget::contained(Circuit *rootnet)
+{	Circuit *_rootnet = activeNet;
 
 	if (_rootnet == rootnet) return 1;
 	while(NULL != (_rootnet = _rootnet->parent())) {
@@ -1206,7 +1216,7 @@ void NetWidget::simStep()
 	// runtime shortcut occured?
 	if (ret == WSHORT && runtimeShortcutWarning) {
 		if (simmode == MODE_SIM_MULT) simTimer.stop();
-		QMessageBox::warning(_parent,
+		QMessageBox::warning(m_oParent,
 			i18n("runtime error"),
 			i18n("shortcut\n"));
 		if (simmode == MODE_SIM_MULT) simTimer.start(STATsimStepTime);
@@ -1216,7 +1226,7 @@ void NetWidget::simStep()
 }
 
 // private slot
-// enable runtime shortcut warning again, 10sec ather the last one
+// enable runtime shortcut warning again, 10sec after the last one
 void NetWidget::enableShortcutWarning()
 {
 	runtimeShortcutWarning = true;
@@ -1224,14 +1234,14 @@ void NetWidget::enableShortcutWarning()
 
 // public slot
 // update visible rect, emitted by MainWidget
-void NetWidget::visible(QRect newvisi)
+void NetWidget::visible(const QRect& newvisi)
 {
-	visi = newvisi;
+	m_oVisibleRect = newvisi;
 }
 
 // apply device defaults to all existing devices
 void NetWidget::applyDefaults()
-{	XDeviceNet *toplevel = activeNet->rootParent();
+{	Circuit *toplevel = activeNet->rootParent();
 
 	toplevel->applyDefaults();
 	repaint(TRUE);
