@@ -1,5 +1,5 @@
 /*************************************************/
-/* old methods for classes XDeviceNet XDevice,   */
+/* old methods for classes Circuit XDevice,   */
 /* Device and XWire                              */
 /*************************************************/
 #include <qfile.h>
@@ -12,16 +12,35 @@
 #include "klogic.h"
 #include "klogicIO.h"
 #include "netw.h"
-#include "xnet.h"
+#include "circuit.h"
 #include "xwire.h"
 #include "deviceTypes.h"
 #include "deviceOsc.h"
+#include "devicePwr.h"
+#include "deviceSwitch.h"
+
+#define DLM 1 // string delimiter (io operations): ctrl-A
 
 /***************************************************/
 /* import/export operations on a net-widget        */
 /***************************************************/
+// get subnet-pointer by name (used by import methods)
+Circuit * Circuit::subCircuit(QString& s)
+{
+        KlogicList<Circuit> *ln;
+        int epos;
+        QString sid;
 
-QString XDeviceNet::exportInstance()
+        epos = s.find(DLM, 0);
+        if (epos == -1) epos = s.length();
+        sid = s.mid(1, epos - 1);
+
+        ln = netnet.With(devmap.mapID(sid));
+        if (ln) return ln->Get();
+        return (Circuit *)NULL;
+}
+
+QString Circuit::exportInstance()
 {	QString buf;
 
 	QString s = device2string(0, 0);
@@ -35,7 +54,7 @@ QString XDeviceNet::exportInstance()
 
 // export all wires of this net
 // to export only the selected objects, call with selonly=1
-QString XDeviceNet::exportWires(int selonly, int dx, int dy)
+QString Circuit::exportWires(int selonly, int dx, int dy)
 {
 	KlogicList<XWire> *lw = netwire.First();
 	QString s, ws;
@@ -57,7 +76,7 @@ QString XDeviceNet::exportWires(int selonly, int dx, int dy)
 }
 
 // to export only the selected objects, call with selonly=1
-QString XDeviceNet::exportDevices(int selonly, int dx, int dy)
+QString Circuit::exportDevices(int selonly, int dx, int dy)
 {
 	KlogicList<XDevice> *ld = netdev.First();
 	XDevice *d;
@@ -75,7 +94,7 @@ QString XDeviceNet::exportDevices(int selonly, int dx, int dy)
 }
 
 // to export only the selected objects, call with selonly=1
-QString XDeviceNet::exportWireConn(int selonly, int dx, int dy)
+QString Circuit::exportWireConn(int selonly, int dx, int dy)
 {
 	KlogicList<XWire> *lw = netwire.First();
 	XWire *w;
@@ -126,7 +145,7 @@ QString XDeviceNet::exportWireConn(int selonly, int dx, int dy)
 }
 
 // to export only the selected objects, call with selonly=1
-QString XDeviceNet::exportDevConn(int selonly, int dx, int dy)
+QString Circuit::exportDevConn(int selonly, int dx, int dy)
 {
 	KlogicList<XWire> *lw = netwire.First();
 	XDevice *d;
@@ -207,20 +226,20 @@ QString XDeviceNet::exportDevConn(int selonly, int dx, int dy)
 	return s;
 }
 
-void XDeviceNet::initImport()
+void Circuit::initImport()
 {
 	wiremap.init();
 	devmap.init();
 }
 
 // reading a sub circuit from file: create a new sub circuit device and initialize it
-bool XDeviceNet::importInstance(QString s, int dx, int dy)
+bool Circuit::importInstance(QString s, int dx, int dy)
 {
 	// newer files have some kind of version number ..
-	if (!XDeviceNet::magic_version) {
+	if (!Circuit::magic_version) {
 		int posa = s.findRev(DLM);
 		if (posa != -1) {	// of course not!
-			XDeviceNet::magic_version = s.right(s.length() - posa - 1).toInt();
+			Circuit::magic_version = s.right(s.length() - posa - 1).toInt();
 		}
 	}
 
@@ -229,7 +248,7 @@ bool XDeviceNet::importInstance(QString s, int dx, int dy)
 	return true;
 }
 
-bool XDeviceNet::importWire(QString s, int select, int dx, int dy)
+bool Circuit::importWire(QString s, int select, int dx, int dy)
 {
 	int epos;
 	QString sid;
@@ -258,7 +277,7 @@ bool XDeviceNet::importWire(QString s, int select, int dx, int dy)
 	return true;
 }
 
-bool XDeviceNet::importDevice(QString s, int select, int dx, int dy)
+bool Circuit::importDevice(QString s, int select, int dx, int dy)
 {
 	int apos, epos;
 	int func;
@@ -277,9 +296,9 @@ bool XDeviceNet::importDevice(QString s, int select, int dx, int dy)
 	if (epos == -1) return false;
 	func = s.mid(apos, epos - apos).toInt();
 
-	// create the new device (size of 4 will be overwritten in next step!)
+	// create the new device
 	d = newDevice(func, 0, 0, 4);
-	if (!d) fatal("XDeviceNet::importDevice(): unable to create device ..\n");
+	if (!d) fatal("Circuit::importDevice(): unable to create device ..\n");
 
 	// call member method to import device parameter
 	ret = d->string2device(s, dx, dy);
@@ -292,7 +311,7 @@ bool XDeviceNet::importDevice(QString s, int select, int dx, int dy)
 	if (d->type() == DeviceType::fIN || d->type() == DeviceType::fOUT) {
 		// the text of the i/o-device is currently the old id ... (or -1 if it is an old format)
 		KlogicList<Value> *lv = NULL;
-		KlogicList<opStack> *lop = NULL;
+		KlogicList<Calculator> *lop = NULL;
 		if (d->type() == DeviceType::fIN) {
 			lv = named_input.With(sid);			// access with the old id string
 			if (lv) lv->setID1(d->getID());			// exchange the old id with the new one
@@ -303,14 +322,14 @@ bool XDeviceNet::importDevice(QString s, int select, int dx, int dy)
 		}
 
 		// now set the correct text
-		setText(d->getID(), d->getText());
+		setName(d->getID(), d->getName());
 		setImage();
 	}
 
 	return ret;
 }
 
-bool XDeviceNet::importWireConn(QString s, int, int dx, int dy)
+bool Circuit::importWireConn(QString s, int, int dx, int dy)
 {
 	int apos, epos;
 	XWire *w1, *w2;
@@ -356,7 +375,7 @@ bool XDeviceNet::importWireConn(QString s, int, int dx, int dy)
 	return true;
 }
 
-bool XDeviceNet::importDevConn(QString s, int, int dx, int dy)
+bool Circuit::importDevConn(QString s, int, int dx, int dy)
 {
 	int apos, epos;
 	QString sid;
@@ -458,7 +477,7 @@ QString XDevice::device2string(int dx, int dy)
  
         if (type() != DeviceType::fRAM && type() != DeviceType::fTRI && hasNamedOutput()) {
                 // saving the device id's here ... the text comes with the device itself!
-                KlogicList<opStack> *lo = named_output.First()->Next();       // the first output in the list is an universal unnamed output
+                KlogicList<Calculator> *lo = named_output.First()->Next();       // the first output in the list is an universal unnamed output
                 if (lo) {
                         buf.sprintf("%c%c%d", DLM, 3, lo->counter() - 1);       //CRTL-C
                         ret += buf;
@@ -485,7 +504,7 @@ QString XDevice::device2string(int dx, int dy)
                 }
         }
  
-        buf.sprintf("%c%d", DLM, textDisplayed());
+        buf.sprintf("%c%d", DLM, nameDisplayed());
         ret += buf;
  
         if (type() == DeviceType::fRAM) {
@@ -557,7 +576,7 @@ bool XDevice::string2device(QString s, int dx, int dy)
         }
         pt.setY(xs.mid(apos, epos - apos).toInt() + dy);
 	// the image of switch has changed (only relevant for this import)
-	if (XDeviceNet::magic_version != 1300 && type() == DeviceType::fSWI) {
+	if (Circuit::magic_version != 1300 && type() == DeviceType::fSWI) {
 		pt.setX(pt.x() + 10);
 	}
  
@@ -672,7 +691,7 @@ bool XDevice::string2device(QString s, int dx, int dy)
                         finished = 1;
                         epos = xs.length();
                 }
-                displayText(xs.mid(apos, epos - apos).toInt());
+                displayName(xs.mid(apos, epos - apos).toInt());
         }
  
         if (!finished && type() == DeviceType::fRAM) {
@@ -739,7 +758,7 @@ bool XDevice::string2device(QString s, int dx, int dy)
         if (clock() == OscillatorDevice::CLK_MONO && type() == DeviceType::fOSC) {
                 deviceMaxInput = 1;
         }
-        setText(getText());
+        setName(getName());
  
         if (redraw ||
             type() == DeviceType::fRS || type() == DeviceType::fJK ||
@@ -764,10 +783,10 @@ QString Device::device2string()
         // all other devices
 	int osz_on_cnt = 0, osz_off_cnt = 0, osz_curr_step = 0;
 	if (type() == DeviceType::fOSC) {
-		OscillatorDevice *odev = (OscillatorDevice *)getInstance();
-		osz_on_cnt = odev->oszOn();
-		osz_off_cnt = odev->oszOff();
-		osz_curr_step = odev->getCurrOszStep();
+		OscillatorDevice *poOscDev = (OscillatorDevice *)getInstance();
+		osz_on_cnt = poOscDev->oszOn();
+		osz_off_cnt = poOscDev->oszOff();
+		osz_curr_step = poOscDev->getCurrOszStep();
 	}
         ret.sprintf("%d%c%d%c%d%c%d%c%d%c%d%c%d%c%d%c%d%c%d%c",
                 id, DLM,
@@ -780,7 +799,7 @@ QString Device::device2string()
                 osz_off_cnt, DLM,
                 named_output.Get()->getResult(), DLM,
                 osz_curr_step, DLM);
-        if (text) ret += text;
+        ret += m_sName;
  
         return ret;
 }
@@ -790,9 +809,9 @@ bool Device::string2device(QString s)
         QString original_text;
         QString alternate_text;
  
-	OscillatorDevice *odev = (OscillatorDevice *)NULL;
+	OscillatorDevice *poOscDev = (OscillatorDevice *)NULL;
 	if (type() == DeviceType::fOSC) {
-		odev = (OscillatorDevice *)getInstance();
+		poOscDev = (OscillatorDevice *)getInstance();
 	}
 
         // name
@@ -834,34 +853,42 @@ bool Device::string2device(QString s)
         apos = epos + 1;
         epos = s.find(DLM, apos);
         if (epos == -1) return false;
-        if (odev) odev->setOszOn(s.mid(apos, epos - apos).toInt());
+        if (poOscDev) poOscDev->setOszOn(s.mid(apos, epos - apos).toInt());
  
         // oscillator off time
         apos = epos + 1;
         epos = s.find(DLM, apos);
         if (epos == -1) return false;
-        if (odev) odev->setOszOff(s.mid(apos, epos - apos).toInt());
+        if (poOscDev) poOscDev->setOszOff(s.mid(apos, epos - apos).toInt());
+
+	// output value
+	apos = epos + 1;
+	epos = s.find(DLM, apos);
+	if (epos == -1) return false;
+	flush(s.mid(apos, epos - apos).toInt());
+
+	if (type() == DeviceType::fPWR) {
+		PowerDevice *poPwrDev = (PowerDevice *)getInstance();
+		poPwrDev->setStaticInput(s.mid(apos, epos - apos).toInt());
+	}
+	if (type() == DeviceType::fSWI) {
+		SwitchDevice *poSwDev = (SwitchDevice *)getInstance();
+		poSwDev->setStaticInput(s.mid(apos, epos - apos).toInt());
+	}
  
-        // output value
-        apos = epos + 1;
-        epos = s.find(DLM, apos);
+	// osz_curr_step
+	apos = epos + 1;
+	epos = s.find(DLM, apos);
         if (epos == -1) return false;
-        flush(s.mid(apos, epos - apos).toInt());
-        setStaticInput(s.mid(apos, epos - apos).toInt());
- 
-        // osz_curr_step
-        apos = epos + 1;
-        epos = s.find(DLM, apos);
-        if (epos == -1) return false;
-        if (odev) odev->setCurrOszStep(s.mid(apos, epos - apos).toInt());
+        if (poOscDev) poOscDev->setCurrOszStep(s.mid(apos, epos - apos).toInt());
 
         // text label
         apos = epos + 1;
         epos = s.find(DLM, apos);
         if (epos == -1) return false;
         original_text = s.mid(apos, epos - apos);
-        if (original_text.length() > 0) setText((char *)(const char *)original_text);
-        else setText((char *)(const char *)alternate_text);
+        if (original_text.length() > 0) setName((char *)(const char *)original_text);
+        else setName((char *)(const char *)alternate_text);
  
         return true;
 }
