@@ -12,8 +12,10 @@
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
-#include <xwire.h>
-#include <klogic.h>
+
+#include "xwire.h"
+#include "klogic.h"
+#include "grid.h"
 
 /***************************************************/
 /* methods of Wire                                 */
@@ -215,8 +217,8 @@ void Wire::setLineSize(int new_size)
 	if (size != new_size) {
 		old_size = size;
 		enforceCompleteDrawing();
+		size = new_size;
 	}
-	size = new_size;
 }
 
 int Wire::lockSelectedNode()
@@ -254,7 +256,7 @@ void Wire::addPos(int dx, int dy)
 
 // creates new node, if not i/o and not end-node
 // otherwise locks the node
-int Wire::createNode(QPoint p)
+int Wire::createNode(const QPoint& p)
 {	KlogicList<QPoint> *l;
 	QPoint *pt;
 
@@ -798,8 +800,8 @@ void Wire::restoreArry(QPainter *p, int x1, int y1, int x2, int y2)
 		d = y1;
 		c = y2;
 	}
-	for(i=a;i <= b;i += GRID) {
-		for(j=c; j <= d; j += GRID) {
+	for(i=a;i <= b;i += Grid::GRID) {
+		for(j=c; j <= d; j += Grid::GRID) {
 			p->drawPoint(i,j);
 		}
 	}
@@ -815,8 +817,8 @@ void Wire::updateNode(QPoint p)
 }
 
 QPoint *Wire::align(QPoint *p)
-{	p->setX((p->x() + GRIDHALF) / GRID * GRID);
-	p->setY((p->y() + GRIDHALF) / GRID * GRID);
+{	p->setX((p->x() + Grid::GRIDHALF) / Grid::GRID * Grid::GRID);
+	p->setY((p->y() + Grid::GRIDHALF) / Grid::GRID * Grid::GRID);
 	return p;
 }
 
