@@ -16,10 +16,12 @@
 #include "xwire.h"
 #include "xdevice.h"
 #include "klogic.h"
-#include "opStack.h"
+#include "calculator.h"
 #include "value.h"
 #include "deviceTypes.h"
 #include "busOutputArray.h"
+#include "deviceText.h"
+#include "grid.h"
 
 /***************************************************/
 /* static methods of XDevice class                 */
@@ -129,13 +131,13 @@ void XDevice::setDefInverted(bool newi)
 }
 
 // static method
-void XDevice::displayTextGlobal(bool flag)
+void XDevice::displayNameGlobal(bool flag)
 {
 	STATdisplay_name = flag;
 }
 
 // static method
-bool XDevice::textDisplayedGlobal()
+bool XDevice::nameDisplayedGlobal()
 {
 	return STATdisplay_name;
 }
@@ -334,21 +336,13 @@ XDevice::XDevice(int function, int x, int y, int size, int delay, int undef, int
 	else
 		deviceOutputInverted = STATdef_inverted;
 
-	editable = true;
-	switch_type = true;
 	deviceMaxInput = MAXI;
 	deviceMaxOutput = MAXO;
 	graph_enabled = true;
-	text_dev = (XDevice *)NULL;
+	m_oTextDev = 0;
 	tristate_input_moved = 0;
 	tristate_pos_import = 0;
 	deviceWidth = 1;
-
-	init();
-	if (!Device::IMPORT_IGNORE_GLOBAL) setImage();
-	setEquation();
-	parseEquation();
-	if (STATdisplay_name && function != DeviceType::fTXT) displayText(true);
 }
 
 // remove device: remove all inputs and outputs first
@@ -374,7 +368,7 @@ XDevice::~XDevice()
 	}
 	out_w.Destroy();
 
-	if (text_dev) delete text_dev;
+	if (m_oTextDev) delete m_oTextDev;
 }
 
 int XDevice::contains(QPoint pt)
@@ -425,7 +419,7 @@ bool XDevice::setSize(int new_s)
 			maxy = w->getOutputPosition(idx).y() - getPos().y();
 		lw = lw->Next();
 	}
-	maxy = maxy / GRID;
+	maxy = maxy / Grid::GRID;
 	if (maxy > min_size) min_size = maxy;
 
 	if (new_s > min_size) {
@@ -443,7 +437,7 @@ bool XDevice::setSize(int new_s)
 int XDevice::neededSize()
 {	int new_size = MINSIZE;
 
-	KlogicList<opStack> *lop = named_output.First();
+	KlogicList<Calculator> *lop = named_output.First();
 	while(lop) {
 		if ((lop->Get()->getPosition() + 1) > new_size)
 			new_size = lop->Get()->getPosition();
@@ -471,7 +465,6 @@ bool XDevice::sizeChangeable()
             function == DeviceType::fLEDgreen ||
             function == DeviceType::fLEDyellow ||
             function == DeviceType::fDFF ||
-            function == DeviceType::fSWI ||
             function == DeviceType::fTRI ||
             function == DeviceType::fONE);
 }
@@ -502,11 +495,6 @@ void XDevice::setMaxO(int newmax)
 	else deviceMaxOutput = newmax;
 }
 
-// flag for the device-properties-dialog
-bool XDevice::isEditable()
-{	return editable;
-}
-
 // output inverted by default?
 bool XDevice::isInverted()
 {	return deviceOutputInverted;
@@ -520,12 +508,12 @@ void XDevice::setInverted(bool flag)
 }
 
 // virtual
-void XDevice::setText(const QString& new_text)
+void XDevice::setName(const QString& sName)
 {
-	Device::setText(new_text);
+	Device::setName(sName);
 
-        if (text_dev) {
-                text_dev->setText(new_text);
+        if (m_oTextDev) {
+                m_oTextDev->setName(sName);
                 setTextDevPos();
         }
 
@@ -533,56 +521,38 @@ void XDevice::setText(const QString& new_text)
 }
 
 // show/hide the name of the display
-void XDevice::displayText(bool flag)
+void XDevice::displayName(bool flag)
 {
-	if (type() == DeviceType::fTXT) return;
 	if (!getID()) return;
 	if (flag) {
-		if (text_dev) return;
-		text_dev = new XDevice(DeviceType::fTXT, 0, 0);
-		QString txt = getText();
+		m_oTextDev = new TextDevice(0, 0);
+		QString txt = getName();
 		if (txt.isEmpty()) txt = " ";
-		text_dev->setText(txt);
+		m_oTextDev->setName(txt);
 
 		QRect dpos = getPos();
-		QRect tpos = text_dev->getPos();
+		QRect tpos = m_oTextDev->getPos();
 		QPoint _newpos;
 		_newpos.setX(dpos.x() + dpos.width() / 2 - tpos.width() / 2);
 		_newpos.setY(dpos.y() - tpos.height());
-		text_dev->setVOffset(-3);
-		text_dev->setHOffset(-XObject::IOREG);
-		text_dev->initPos(_newpos.x(), _newpos.y());
+		m_oTextDev->setVOffset(-3);
+		m_oTextDev->setHOffset(-XObject::IOREG);
+		m_oTextDev->initPos(_newpos.x(), _newpos.y());
                 setTextDevPos();
 	} else {
-		if (!text_dev) return;
-		delete text_dev;
-		text_dev = (XDevice *)NULL;
+		if (!m_oTextDev) return;
+		delete m_oTextDev;
+		m_oTextDev = 0;
 	}
 }
 
 // is the name of the device shown/hidden
-bool XDevice::textDisplayed()
+bool XDevice::nameDisplayed()
 {
-	if (text_dev) return true;
+	if (m_oTextDev) return true;
 	return false;
 }
 
-// is the device a swith or a push button? (fSWI only)
-bool XDevice::isSwitchType()
-{
-	return switch_type;
-}
-
-// set wether this fSWI is a swith or a push button (fSWI only)
-void XDevice::setSwitchType(bool new_type)
-{
-	if (new_type == switch_type) return;
-	if (type() != DeviceType::fSWI) return;
-
-	switch_type = new_type;
-	if (!Device::IMPORT_IGNORE_GLOBAL) setImage();
-}
-
 // set all output to tristate enabled
 // add/remove "EN" input
 void XDevice::setTristate(bool flag)
@@ -685,9 +655,7 @@ void XDevice::setClock(int new_clk)
 // draw a graph in the simulation graph widget?
 bool XDevice::drawGraph()
 {
-	if ((type() != DeviceType::fPWR) && (maxO()))
-		return true;
-	return false;
+	return maxO();
 }
 
 // returns if device should be shown in the simulation graph
@@ -746,7 +714,7 @@ void XDevice::setWidth(int new_width)
 void XDevice::erase(QPainter *p)
 {	KlogicList<XWire> *l;
 
-	if (text_dev) text_dev->erase(p);
+	if (m_oTextDev) m_oTextDev->erase(p);
 
 	updateWires();
 	l = in_w.First();
@@ -858,13 +826,12 @@ int XDevice::checkInput(XWire *w, int found, int invert)
 		// connections in all points allowed
 		if (!hasNamedInput()) {
 			return connectInput(w, p, invert);
-		}
-		// connections only in some points allowed (named inputs)
-		else {
+		} else {
+			// connections only in some points allowed (named inputs)
 			while (li) {
 				new_id = li->getID1();
 				ap.setX(getPos().x());
-				ap.setY(li->Get()->getPosition() * GRID + getPos().y() + getVOffset());
+				ap.setY(li->Get()->getPosition() * Grid::GRID + getPos().y() + getVOffset());
 				if (ap == p) return connectInput(w, p, invert, new_id);
 				li = li->Next();
 			}
@@ -884,7 +851,7 @@ int XDevice::checkInput(XWire *w, int found, int invert)
 			while (li && !isconn) {
 				new_id = li->getID1();
 				ap.setX(getPos().x());
-				ap.setY(li->Get()->getPosition() * GRID + getPos().y() + getVOffset());
+				ap.setY(li->Get()->getPosition() * Grid::GRID + getPos().y() + getVOffset());
 				if (ap == p) isconn = 1;
 				li = li->Next();
 			}
@@ -932,7 +899,26 @@ int XDevice::checkOutput(XWire *w, int found, int invert)
 
 	if (!found) {
 		// check output connection
-		if (!output_region.contains(p)) return DOK;
+		if (!output_region.contains(p)) {
+			// fSWI became smaller .. workaround in order to load old files!
+			if (type() == DeviceType::fSWI) {
+				output_region.setWidth(output_region.width() + 10);
+				if (!output_region.contains(p)) {
+					output_region.setHeight(output_region.height() + 10);
+					if (!output_region.contains(p)) {
+						return DOK;
+					} else {
+						p.setY(p.y() - 10);
+						w->updateNode(p);
+					}
+				} else {
+					p.setX(p.y() - 10);
+					w->updateNode(p);
+				}
+			} else {
+				return DOK;
+			}
+		}
 
 		if (!hasNamedOutput()) {
 			if (XWire::WFAIL != w->activeIsOutput()) return DOK;
@@ -941,12 +927,12 @@ int XDevice::checkOutput(XWire *w, int found, int invert)
 		}
 		// connections in some points allowed only
 		else {
-			KlogicList<opStack> *lo = named_output.First()->Next();
+			KlogicList<Calculator> *lo = named_output.First()->Next();
 			while (lo) {
 				if (!lo->Get()->isInternal()) {
 					new_id = lo->getID1();
 					ap.setX(r.x() + r.width() - 1);
-					ap.setY(lo->Get()->getPosition() * GRID + r.y() + getVOffset());
+					ap.setY(lo->Get()->getPosition() * Grid::GRID + r.y() + getVOffset());
 					if (ap == p) return connectOutput(w, p, invert, new_id);
 				}
 				lo = lo->Next();
@@ -967,12 +953,12 @@ int XDevice::checkOutput(XWire *w, int found, int invert)
 			}
 		}
 		else {
-			KlogicList<opStack> *lo = named_output.First()->Next();
+			KlogicList<Calculator> *lo = named_output.First()->Next();
 			while (lo && !isconn) {
 				if (!lo->Get()->isInternal()) {
 					new_id = lo->getID1();
 					ap.setX(r.x() + r.width() - 1);
-					ap.setY(lo->Get()->getPosition() * GRID + r.y() + getVOffset());
+					ap.setY(lo->Get()->getPosition() * Grid::GRID + r.y() + getVOffset());
 					if (ap == p) isconn = 1;
 				}
 				lo = lo->Next();
@@ -1329,7 +1315,7 @@ int XDevice::addOutputName(const QString& nam, int pos, int dev_id)
 {	int y = pos;
 	int maxy = size();
 	int found = 1;
-	KlogicList<opStack> *lo;
+	KlogicList<Calculator> *lo;
 
 	// ignore ...
 	if (!nam.length() || !nam.compare("(null)")) return ADDNAMED_OK;
@@ -1414,8 +1400,7 @@ void XDevice::setImage()
 	QPainter p;
 	QPoint pt(0,0);
 	QPoint pp(15,35);
-	QRect _rect;
-	KlogicList<opStack> *lop;
+	KlogicList<Calculator> *lop;
 	KlogicList<Value> *lv;
 	int i;
 	int pos;
@@ -1426,20 +1411,6 @@ void XDevice::setImage()
 
 	// first resize the device pixmap, assign the base image to "part"..
 	switch (this->type()) {
-		case DeviceType::fTXT:
-			p.begin(pic);
-			p.setFont(STATfont);
-			_rect = p.boundingRect(1000, 1000, 1000, 1000, Qt::AlignLeft, getText());
-			p.end();
-			if (_rect.width() < 1) _rect.setWidth(10);
-			if (_rect.height() < 1) _rect.setHeight(8);
-			pic->resize(_rect.width() + 4, _rect.height());
-			break;
-		case DeviceType::fPWR:
-			if (output()) part = pxPOS;
-			else part = pxNEG;
-			pic->resize(part->width(), part->height());
-			break;
 		case DeviceType::fRS:
 			if (!hasMaster()) {
 				if (clock() == CLK_NONE) part = pxRS;
@@ -1455,9 +1426,6 @@ void XDevice::setImage()
 			else part = pxD;
 			pic->resize(part->width(), part->height());
 			break;
-		case DeviceType::fSWI:
-			pic->resize(pxSWI0->width(), pxSWI0->height());
-			break;
 		case DeviceType::fSS:
 			pic->resize(pxSSB->width(), pxSSB->height());
 			break;
@@ -1473,12 +1441,6 @@ void XDevice::setImage()
 		case DeviceType::fLEDyellow:
 			pic->resize(pxLED0yellow->width(), pxLED0yellow->height());
 			break;
-		case DeviceType::fIN:
-			pic->resize(pxIN->width(), pxIN->height());
-			break;
-		case DeviceType::fOUT:
-			pic->resize(pxOUT->width(), pxOUT->height());
-			break;
 		case DeviceType::fTRI:
 		case DeviceType::fEQU:
 		case DeviceType::fNET:
@@ -1507,19 +1469,6 @@ void XDevice::setImage()
 
 	// ..then draw the device image
 	switch (this->type()) {
-		case DeviceType::fTXT:
-			p.setBrush(Qt::white);
-			p.setPen(Qt::black);
-			p.drawRect(pic->rect());
-			p.setFont(STATfont);
-			p.drawText(3, pic->height() - 2, getText());
-			setVOffset(-3);
-			break;
-		case DeviceType::fPWR:
-			if (!part) fatal("no pixmap??");
-			p.drawPixmap(pt, *part);
-			setVOffset(5);
-			break;
 		case DeviceType::fRS:
 			if (!part) fatal("no pixmap??");
 			p.drawPixmap(pt, *part);
@@ -1542,13 +1491,9 @@ void XDevice::setImage()
 			if (!part) fatal("no pixmap??");
 			p.drawPixmap(pt, *part);
 			break;
-		case DeviceType::fSWI:
-			p.drawPixmap(pt, *pxSWI0);
-			setHOffset(-2);
-			break;
 		case DeviceType::fSS:
 			p.drawPixmap(pt, *pxSSB);
-			pp.setX(pic->width()/2 - sySS->width()/2 + GRIDHALF - 3);
+			pp.setX(pic->width()/2 - sySS->width()/2 + Grid::GRIDHALF - 3);
 			pp.setY(pic->height()/2 - sySS->height()/2);
 			p.drawPixmap(pp, *pxSS[0]);
 			break;
@@ -1564,20 +1509,6 @@ void XDevice::setImage()
 		case DeviceType::fLEDyellow:
 			p.drawPixmap(pt, *pxLED0yellow);
 			break;
-		case DeviceType::fIN:
-			p.drawPixmap(pt, *pxIN);
-			// draw symbol
-			p.setFont(STATfont);
-			p.drawText(10, 9, getText());
-			setVOffset(5);
-			break;
-		case DeviceType::fOUT:
-			p.drawPixmap(pt, *pxOUT);
-			// draw symbol
-			p.setFont(STATfont);
-			p.drawText(10, 9, getText());
-			setVOffset(5);
-			break;
 		case DeviceType::fTRI:
 		case DeviceType::fEQU:
 		case DeviceType::fNET:
@@ -1615,10 +1546,10 @@ void XDevice::setImage()
 			xdistance = XObject::IOREG + 3;
 			while(lv) {
 				if (!lv->Get()->isInternal()) {
-					pos = lv->Get()->getPosition() * GRID;
+					pos = lv->Get()->getPosition() * Grid::GRID;
 					if (lv->Get()->getPosition() == 0)
 						p.drawText(xdistance, pos + 7, lv->getText());
-					else if (pos == (size() * GRID))
+					else if (pos == (size() * Grid::GRID))
 						p.drawText(xdistance, pos + 5, lv->getText());
 					else 
 						p.drawText(xdistance, pos + 6, lv->getText());
@@ -1630,11 +1561,11 @@ void XDevice::setImage()
 			xwidth = xdistance - 6;
 			while(lop) {
 				if (!lop->Get()->isInternal()) {
-					pos = lop->Get()->getPosition() * GRID;
+					pos = lop->Get()->getPosition() * Grid::GRID;
 					if (pos == 0)
 						p.drawText(xdistance, pos - 2, xwidth, 10,
 							Qt::AlignRight, lop->getText());
-					else if (pos == (size() * GRID))
+					else if (pos == (size() * Grid::GRID))
 						p.drawText(xdistance, pos - 4 , xwidth, 10,
 							Qt::AlignRight, lop->getText());
 					else 
@@ -1737,7 +1668,7 @@ void XDevice::setImage()
 
 	p.end();
 
-	if (text_dev) text_dev->setImage();
+	if (m_oTextDev) m_oTextDev->setImage();
 }
 
 int XDevice::setPos(QPoint newpos)
@@ -1750,21 +1681,21 @@ int XDevice::setPos(QPoint newpos)
 
 void XDevice::setTextDevPos()
 {
-	if (!text_dev) return;
+	if (!m_oTextDev) return;
 
 	QRect dpos = getPos();
-	QRect tpos = text_dev->getPos();
+	QRect tpos = m_oTextDev->getPos();
 	QPoint _newpos;
 	_newpos.setX(dpos.x() + dpos.width() / 2 - tpos.width() / 2);
 	_newpos.setY(dpos.y() - tpos.height());
-	text_dev->setPos(_newpos);
+	m_oTextDev->setPos(_newpos);
 }
 
 // draw device to the screen
 void XDevice::drawImage(QPaintDevice *paintd, QPainter *p)
 {
 	XObject::drawImage(paintd, p);
-	if (text_dev) text_dev->drawImage(paintd, p);
+	if (m_oTextDev) m_oTextDev->drawImage(paintd, p);
 }
 
 // draw device as lines and text to a printer device
@@ -1814,11 +1745,10 @@ void XDevice::drawImage(QPainter *p)
 void XDevice::printImage(QPainter *p, const QRect& r)
 {
 	KlogicList<Value> *lv;
-	KlogicList<opStack> *lop;
+	KlogicList<Calculator> *lop;
 	int pos;
 	int a,b,c,d,e;
 	int picwidth = getImage()->width();
-	QRect rr(r);
 
 	// draw io-names and type specific symbol
 	switch(type()) {
@@ -1828,7 +1758,7 @@ void XDevice::printImage(QPainter *p, const QRect& r)
 			p->setFont(STATfont);
 			lv = named_input.First();
 			while(lv) {
-				pos = lv->Get()->getPosition() * GRID;
+				pos = lv->Get()->getPosition() * Grid::GRID;
 				if (type() == DeviceType::fDFF && strcmp(lv->getText(), "C1") == 0 && hasMaster()) {
 					a = r.x();
 					b = r.x() + 6;
@@ -1839,7 +1769,7 @@ void XDevice::printImage(QPainter *p, const QRect& r)
 				} else {
 					if (pos == 0)
 						p->drawText(r.x() + 1, r.y() + pos + 7, lv->getText());
-					else if (pos == (size() * GRID))
+					else if (pos == (size() * Grid::GRID))
 						p->drawText(r.x() + 1, r.y() + pos + 5, lv->getText());
 					else
 						p->drawText(r.x() + 1, r.y() + pos + 6, lv->getText());
@@ -1852,11 +1782,11 @@ void XDevice::printImage(QPainter *p, const QRect& r)
 			} else {
 				lop = named_output.First();
 				while(lop) {
-					pos = lop->Get()->getPosition() * GRID;
+					pos = lop->Get()->getPosition() * Grid::GRID;
 					if (pos == 0)
 						p->drawText(r.x() + (picwidth / 2), r.y() + pos - 2,
 							picwidth / 2 - 7, 10, Qt::AlignRight, lop->getText());
-					else if (pos == (size() * GRID))
+					else if (pos == (size() * Grid::GRID))
 						p->drawText(r.x() + (picwidth / 2), r.y() + pos - 4,
 							picwidth / 2 - 7, 10, Qt::AlignRight, lop->getText());
 					else
@@ -1866,14 +1796,6 @@ void XDevice::printImage(QPainter *p, const QRect& r)
 				}
 			}
 			break;
-		case DeviceType::fIN:
-			p->setFont(STATfont);
-			p->drawText(r.x() + 6, r.y() + 9, getText());
-			break;
-		case DeviceType::fOUT:
-			p->setFont(STATfont);
-			p->drawText(r.x() + 6, r.y() + 9, getText());
-			break;
 		case DeviceType::fAND:
 			p->setFont( QFont( "helvetica", 16, QFont::Bold ) );
 			p->drawText(r.x() + (picwidth / 2) - 8, r.y() + (r.height() / 2) + 5, "&");
@@ -1891,18 +1813,6 @@ void XDevice::printImage(QPainter *p, const QRect& r)
 			p->setFont( QFont( "helvetica", 16, QFont::Bold ) );
 			p->drawText(r.x() + (picwidth / 2) - 8, r.y() + (r.height() / 2) + 5, "1");
 			break;
-		case DeviceType::fSWI:
-			rr.setY(r.y() + 12);
-			rr.setHeight(r.height() - 20);
-			p->drawRect(rr);
-			a = rr.x() + 8;
-			b = rr.x() + rr.width() - 7;
-			c = rr.y() + (rr.height() / 2) + 1;
-			p->drawLine(rr.x() + 2, c, a, c);
-			p->drawLine(b, c, rr.x() + rr.width() - 2, c);
-			p->drawLine(a, c, b + 1, c - 3);
-			p->drawLine(b, c, b, c - 4);
-			break;
 		case DeviceType::fSS:
 		case DeviceType::fLEDred:
 		case DeviceType::fLEDblue:
@@ -1928,17 +1838,6 @@ void XDevice::printImage(QPainter *p, const QRect& r)
 			p->drawLine(a + 1, d - 2, a + 2, d - 2);
 			p->drawLine(a + 2, d - 2, a + 2, d - 1);
 			break;
-		case DeviceType::fPWR:
-			a = r.x() + 2;
-			b = r.y() + (r.height() / 2) + 2;
-			c = r.x() + r.width() - XObject::IOREG - 2;
-			d = r.x() + ((r.width() - XObject::IOREG) / 2);
-			p->drawArc(r.x(), r.y() + 3, r.width() - XObject::IOREG, r.height() - 3, 0, 5760);
-			p->drawLine(a, b, c, b);
-			if (output()) p->drawLine(d, r.y() + 5, d, r.y() + r.height() - 2);
-			// extended connection line
-			p->drawLine(r.x() + r.width() - XObject::IOREG, b, r.x() + r.width(), b);
-			break;
 		default:
 			break;
 	}
@@ -2039,11 +1938,6 @@ void XDevice::init()
 			setSize(MINSIZE);
 			deviceMaxInput = 1;
 			break;
-		case DeviceType::fPWR:
-			deviceOutputInverted = false;
-			deviceMaxInput = 0;
-			deviceMaxOutput = 1;
-			break;
 		case DeviceType::fSS:
 			deviceOutputInverted = false;
 			deviceMaxInput = 4;
@@ -2061,27 +1955,6 @@ void XDevice::init()
 			deviceMaxInput = 4;
 			deviceMaxOutput = 0;
 			break;
-		case DeviceType::fSWI:
-			deviceOutputInverted = false;
-			deviceMaxInput = 0;
-			editable = false;
-			break;
-		case DeviceType::fIN:
-			deviceOutputInverted = false;
-			deviceMaxInput = 0;
-			editable = false;
-			break;
-		case DeviceType::fOUT:
-			deviceOutputInverted = false;
-			deviceMaxOutput = 0;
-			editable = false;
-			break;
-		case DeviceType::fTXT:
-			deviceOutputInverted = false;
-			setSize(MINSIZE);
-			deviceMaxInput = 0;
-			deviceMaxOutput = 0;
-			break;
 		case DeviceType::fRS:
 			deviceOutputInverted = false;
 			addInputName(INPUT_FF_S, 0);
@@ -2115,12 +1988,22 @@ void XDevice::init()
 			setSize(neededSize());
 			break;
 	}
+
+	if (!Device::IMPORT_IGNORE_GLOBAL) setImage();
+	setEquation();
+	parseEquation();
+	if (STATdisplay_name && type() != DeviceType::fTXT)
+		displayName(true);
 }
 
 // calculation method:
 // modifies image of a device in dependance of input
 bool XDevice::setColor()
-{	QString path;
+{
+	if (!outputChanged())
+		return false;
+
+	QString path;
 	QPixmap *pic = getImage();
 	QPixmap *img = (QPixmap *)NULL;
 	QPoint pp(15,35);
@@ -2128,8 +2011,6 @@ bool XDevice::setColor()
 	QString value;
 	int val;
 
-	if (!this->outputChanged()) return false;
-
 	// determine current value-dependant image
 	switch(this->type()) {
 	case DeviceType::fLEDred:
@@ -2173,23 +2054,12 @@ bool XDevice::setColor()
 		}
 		img = pxSS[val];
 		p.begin(pic);
-		pp.setX(pic->width()/2 - (img->width()/2) + GRIDHALF - 3);
+		pp.setX(pic->width()/2 - (img->width()/2) + Grid::GRIDHALF - 3);
 		pp.setY(pic->height()/2 - img->height()/2);
 		p.drawPixmap(pp, *img);
 		p.end();
 		return true;
 		break;
-	case DeviceType::fSWI:
-		if (this->output()) img = pxSWI1;
-		else img = pxSWI0;
-		p.begin(pic);
-		pp.setX(0);
-		pp.setY(0);
-		p.drawPixmap(pp, *img);
-		drawConnectionLines(&p);
-		p.end();
-		return true;
-		break;
 	}
 	return false;
 }
