@@ -4,12 +4,13 @@
 #include <qxml.h>
 
 #include "klogic.h"
-#include "xnet.h"
+#include "circuit.h"
 #include "xdevice.h"
 #include "deviceTypes.h"
 #include "xwire.h"
 #include "xmlImport.h"
 #include "xmlExport.h"
+#include "xmlSymbolMap.h"
 
 /*******************************************/
 /* very restriced XML line parser          */
@@ -43,7 +44,7 @@ void XmlLineParser::setLine(const QString& line)
 	// end tag only
 	if (tagstart1 == tagstart2) {
 		sTag = line.mid(tagstart2 + 2, line.length() - tagstart2 - 3);
-		iTag = XmlObject::getID(sTag);
+		iTag = XmlSymbolMap::m_oMap[sTag];
 		endTag = true;
 		content = line.left(tagstart2);
 		return;
@@ -69,7 +70,7 @@ void XmlLineParser::setLine(const QString& line)
 			endTag = true;
 		} else endTag = false;
 
-		iTag = XmlObject::getID(sTag);
+		iTag = XmlSymbolMap::m_oMap[sTag];
 		content = line.right(line.length() - tagend1 - 1);
 		return;
 	}
@@ -84,7 +85,7 @@ void XmlLineParser::setLine(const QString& line)
 		sTag = __tag;
 		attributes.truncate(0);
 	}
-	iTag = XmlObject::getID(sTag);
+	iTag = XmlSymbolMap::m_oMap[sTag];
 	endTag = true;
 	content = line.mid(tagend1 + 1, tagstart2 - tagend1 - 1);
 }
@@ -129,7 +130,7 @@ QString XMLImportHandler::error_msg = "";
 
 // static
 // import a xml file either into the given _net (sub circuit) or using the _net as main circuit
-bool XMLImportHandler::import(XDeviceNet *_net, bool selected, int dx, int dy, QTextStream & stream)
+bool XMLImportHandler::import(Circuit *_net, bool selected, int dx, int dy, QTextStream & stream)
 {
 	Device::IMPORT_IGNORE_GLOBAL = true;
 
@@ -152,7 +153,7 @@ bool XMLImportHandler::import(XDeviceNet *_net, bool selected, int dx, int dy, Q
 
 // static
 // create a net device from a xml file
-XDevice * XMLImportHandler::import(XDeviceNet *_net, int dx, int dy, QTextStream & stream)
+XDevice * XMLImportHandler::import(Circuit *_net, int dx, int dy, QTextStream & stream)
 {
 	Device::IMPORT_IGNORE_GLOBAL = true;
 
@@ -187,24 +188,24 @@ QString& XMLImportHandler::getErrors()
 	return error_msg;
 }
 
-XMLImportHandler::XMLImportHandler(XDeviceNet *_net, bool selected, int dx, int dy)
+XMLImportHandler::XMLImportHandler(Circuit *_net, bool selected, int dx, int dy)
 {
 	net = _net;
 	imp_selected = selected;
 	imp_dx = dx;
 	imp_dy = dy;
-	importDev = false;
+	m_bImportDev = false;
 	localImport = false;
 	init();
 }
 
-XMLImportHandler::XMLImportHandler(XDeviceNet *_net, int dx, int dy)
+XMLImportHandler::XMLImportHandler(Circuit *_net, int dx, int dy)
 {
 	net = _net;
 	imp_selected = false;
 	imp_dx = dx;
 	imp_dy = dy;
-	importDev = true;
+	m_bImportDev = true;
 	localImport = true;
 	init();
 }
@@ -248,7 +249,7 @@ bool XMLImportHandler::startDocument()
 // to be optimized by error handling!
 bool XMLImportHandler::startElement(const QString&, const QString&, const QString& qName, const QXmlAttributes& atts)
 {
-	int id = XmlObject::getID(qName);
+	int id = XmlSymbolMap::m_oMap[qName];
 	if (!id) {
 		error_msg += i18n("unknown tag");
 		error_msg += "<";
@@ -261,8 +262,8 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 	// -----------------------------------------
 	// main tags
 	// -----------------------------------------
-	if (id == XmlObject::KLOGIC_MAIN) {
-		if (XmlObject::symbolEquals(atts.qName(0), XmlObject::FILE_TYPE)) {
+	if (id == XmlSymbol::KLOGIC_MAIN) {
+		if (XmlSymbolMap::m_oMap.isEqual(atts.qName(0), XmlSymbol::FILE_TYPE)) {
 			if (atts.value(0) == XmlObject::ATT_CIRCUIT)
 				importSub = false;
 			else
@@ -271,7 +272,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 		return true;
 	}
 
-	if (id == XmlObject::CIRCUIT) {
+	if (id == XmlSymbol::CIRCUIT) {
 		if (atts.length() != 5) {
 			error_msg += i18n("circuit: too few attributes\n");
 			error_cnt++;
@@ -283,7 +284,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 
 		int x = imp_dx;
 		int y = imp_dy;
-		if (!importDev) {
+		if (!m_bImportDev) {
 			x += atts.value(3).toInt();
 			y += atts.value(4).toInt();
 		}
@@ -299,7 +300,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 			imp_selected = false;
 		}
 
-		if (!importSub && !importDev) {
+		if (!importSub && !m_bImportDev) {
 			// the very first circuit to be the existing root circuit
 			importSub = true;
 			activeNet[activeNetIdx] = net;
@@ -311,7 +312,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 				error_cnt++;
 				return false;
 			}
-			activeNet[activeNetIdx] = activeDev->devIsNet();
+			activeNet[activeNetIdx] = activeDev->devIsCircuit();
 			if (!activeNet[activeNetIdx]) {
 				error_msg += i18n("unable to create circuit\n");
 				error_cnt++;
@@ -330,18 +331,18 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 		//devmap[activeNetIdx].fileID(circuitID, activeNet[activeNetIdx]->getID());
 
 		// only a device should be imported?
-		if (importDev) {
+		if (m_bImportDev) {
 			imp_dx = 0;
 			imp_dy = 0;
 			importSub = true;
-			importDev = false;
+			m_bImportDev = false;
 			importedDev = activeNet[activeNetIdx];
 		}
 
 		return true;
 	}
 
-	if (id == XmlObject::DEVICE) {
+	if (id == XmlSymbol::DEVICE) {
 		// create devices
 		if (!activeNet[activeNetIdx]) {
 			error_msg += i18n("no parent net for device\n");
@@ -358,7 +359,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 		int size = atts.value(2).toInt();
 		int x = imp_dx;
 		int y = imp_dy;
-		if (!importDev) {
+		if (!m_bImportDev) {
 			x += atts.value(3).toInt();
 			y += atts.value(4).toInt();
 		}
@@ -372,18 +373,23 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 		}
 		devmap[activeNetIdx].fileID(activeID, activeDev->getID());
 
+		// actualize named_input and named_output list id's
+		if (type == DeviceType::fIN || type == DeviceType::fOUT) {
+			activeNet[activeNetIdx]->mapImportID(activeID, activeDev->getID());
+		}
+
 		// only a device should be imported?
-		if (importDev) {
+		if (m_bImportDev) {
 			imp_dx = 0;
 			imp_dy = 0;
 			importedDev = activeDev;
-			importDev = false;
+			m_bImportDev = false;
 		}
 
 		return true;
 	}
 
-	if (id == XmlObject::WIRE) {
+	if (id == XmlSymbol::WIRE) {
 		// create wires
 		if (!activeNet) {
 			error_msg += i18n("no parent net for device\n");
@@ -411,7 +417,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 		return true;
 	}
 
-	if (id == XmlObject::WIRE_CONN) {
+	if (id == XmlSymbol::WIRE_CONN) {
 		// create wire <--> wire connections
 		if (!activeNet) {
 			error_msg += i18n("no parent net for wire <--> wire connections\n");
@@ -439,7 +445,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 		return true;
 	}
 
-	if (id == XmlObject::DEV_CONN) {
+	if (id == XmlSymbol::DEV_CONN) {
 		// create dev <--> wire connections
 		if (!activeNet) {
 			error_msg += i18n("no parent net for wire <--> wire connections\n");
@@ -472,7 +478,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 	// remember the attributes
 	// -----------------------------------------
 	// connections
-	if (id == XmlObject::POS) {
+	if (id == XmlSymbol::POS) {
 		if (atts.length() > 2) {
 			error_msg += i18n("position: too few attributes\n");
 			error_cnt++;
@@ -486,7 +492,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 	}
 
 	// equation devices
-	if (id == XmlObject::OUT_EQU) {
+	if (id == XmlSymbol::OUT_EQU) {
 		if (atts.length() != 3) {
 			error_msg += i18n("equ-device output equations: too few attributes\n");
 			error_cnt++;
@@ -499,7 +505,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 	}
 
 	// equation devices
-	if (id == XmlObject::IN_NAME) {
+	if (id == XmlSymbol::IN_NAME) {
 		if (atts.length() != 2) {
 			error_msg += i18n("equ-device input name: too few attributes\n");
 			error_cnt++;
@@ -511,8 +517,8 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 	}
 
 	// sub circuits
-	if (id == XmlObject::OUT_ID ||
-	    id == XmlObject::IN_ID) {
+	if (id == XmlSymbol::OUT_ID ||
+	    id == XmlSymbol::IN_ID) {
 		if (atts.length() != 1) {
 			error_msg += i18n("sub circuit input/output: too few attributes\n");
 			error_cnt++;
@@ -527,18 +533,18 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 	// process the tags
 	// --------------------------------------------------------------------
 	// device: display text
-	if (id == XmlObject::TEXT_DISP) {
-		if (activeDev) activeDev->displayText(true);
-		else activeNet[activeNetIdx]->displayText(true);
+	if (id == XmlSymbol::TEXT_DISP) {
+		if (activeDev) activeDev->displayName(true);
+		else activeNet[activeNetIdx]->displayName(true);
 	}
 
 	// push button
-	if (id == XmlObject::PUSH) {
-		if (activeDev) activeDev->setSwitchType(false);
+	if (id == XmlSymbol::PUSH) {
+		if (activeDev) activeDev->setToggle(true);
 	}
 
 	// output inverted by default
-	if (id == XmlObject::INV) {
+	if (id == XmlSymbol::INV) {
 		if (activeDev) activeDev->setInverted(true);
 	}
 
@@ -559,7 +565,7 @@ bool XMLImportHandler::characters(const QString& ch)
 
 	// childs of activeNet
 	if (activeWire) {
-		if (id == XmlObject::WIRE) {
+		if (id == XmlSymbol::WIRE) {
 			bool ret = *activeWire << ch;
 			if (!ret) {
 				error_msg += QString::number(characters_call_cnt);
@@ -684,29 +690,29 @@ bool XMLImportHandler::characters(const QString& ch)
 	}
 
 	// these should be handled the very first, so they almost never be checked
-	if (id == XmlObject::PROGRAM_VERSION) {
+	if (id == XmlSymbol::PROGRAM_VERSION) {
 		// informational only
 		// always the current version is stored
 		return true;
 	}
 
-	if (id == XmlObject::CREATION_DATE) {
-		if (!localImport) CurrentCircuit::creation = ch;
+	if (id == XmlSymbol::CREATION_DATE) {
+		if (!localImport) Global::CurrentCircuit::creation = ch;
 		return true;
 	}
 
-	if (id == XmlObject::UPDATE_DATE) {
+	if (id == XmlSymbol::UPDATE_DATE) {
 		// informational only
 		return true;
 	}
 
-	if (id == XmlObject::AUTHOR) {
-		if (!localImport) CurrentCircuit::author = ch;
+	if (id == XmlSymbol::AUTHOR) {
+		if (!localImport) Global::CurrentCircuit::author = ch;
 		return true;
 	}
 
-	if (id == XmlObject::COMMENT) {
-		if (!localImport) CurrentCircuit::comment = ch;
+	if (id == XmlSymbol::COMMENT) {
+		if (!localImport) Global::CurrentCircuit::comment = ch;
 		return true;
 	}
 
@@ -720,58 +726,52 @@ bool XMLImportHandler::setDeviceTag(XDevice *dev, const QString& ch)
 {
 	int id = activeTag[activeTagIdx];
 
-	if (id == XmlObject::TEXT) {
-		activeNet[activeNetIdx]->setText(dev->getID(), ch);
-
-		// actualize named_input and named_output list
-		if (dev->type() == DeviceType::fIN || dev->type() == DeviceType::fOUT) {
-			activeNet[activeNetIdx]->correctIO(dev->getID(), activeID);
-		}
-
+	if (id == XmlSymbol::TEXT) {
+		activeNet[activeNetIdx]->setName(dev->getID(), ch);
 		return true;
 	}
 
-	if (id == XmlObject::DELAY) {
+	if (id == XmlSymbol::DELAY) {
 		dev->setDelay(ch.toInt());
 		return true;
 	}
 
-	if (id == XmlObject::UNDEF) {
+	if (id == XmlSymbol::UNDEF) {
 		dev->setUndef(ch.toInt());
 		return true;
 	}
 
-	if (id == XmlObject::STAT) {
+	if (id == XmlSymbol::STAT) {
 		dev->setStaticInput(ch.toInt());
 		return true;
 	}
 
-	if (id == XmlObject::CLK_TYPE) {
+	if (id == XmlSymbol::CLK_TYPE) {
 		dev->setClock(ch.toInt());
 		return true;
 	}
 
-	if (id == XmlObject::MASTER) {
+	if (id == XmlSymbol::MASTER) {
 		dev->setMaster(ch.toInt());
 		return true;
 	}
 
-	if (id == XmlObject::OSC_ON) {
+	if (id == XmlSymbol::OSC_ON) {
 		dev->setOszOn(ch.toInt());
 		return true;
 	}
 
-	if (id == XmlObject::OSC_OFF) {
+	if (id == XmlSymbol::OSC_OFF) {
 		dev->setOszOff(ch.toInt());
 		return true;
 	}
 
-	if (id == XmlObject::OSC_STEP) {
+	if (id == XmlSymbol::OSC_STEP) {
 		dev->setCurrOszStep(ch.toInt());
 		return true;
 	}
 
-	if (id == XmlObject::RAM) {
+	if (id == XmlSymbol::RAM) {
 		int delim_pos;
 		int curr_pos = 0;
 		if (-1 == (delim_pos = ch.find(';'))) {
@@ -799,13 +799,13 @@ bool XMLImportHandler::setDeviceTag(XDevice *dev, const QString& ch)
 		return true;
 	}
 
-	if (id == XmlObject::TRI) {
+	if (id == XmlSymbol::TRI) {
 		dev->setTristateControlPos(ch.toInt());
 		return true;
 	}
 
 	// equation device output
-	if (id == XmlObject::OUT_EQU) {
+	if (id == XmlSymbol::OUT_EQU) {
 		int dev_id;
 		if (!activeIntern)
 			dev_id = dev->addOutputName(activeName, activePos, 0);
@@ -817,7 +817,7 @@ bool XMLImportHandler::setDeviceTag(XDevice *dev, const QString& ch)
 	}
 
 	// equation device input
-	if (id == XmlObject::IN_NAME) {
+	if (id == XmlSymbol::IN_NAME) {
 		int input_id = ch.toInt();
 		if (!activeIntern) dev->addInputName(ch, activePos, input_id);
 		else dev->addInternalName(ch);
@@ -828,7 +828,7 @@ bool XMLImportHandler::setDeviceTag(XDevice *dev, const QString& ch)
 	// sub circuit output: it's a reference to a device inside
 	// the device name could come in later sections!
 	// the mapping will be done while doing device import for this circuit device
-	if (id == XmlObject::OUT_ID) {
+	if (id == XmlSymbol::OUT_ID) {
 		int output_id_old = ch.toInt();
 		dev->addOutputName(ch, activePos, output_id_old);
 		return true;
@@ -837,30 +837,30 @@ bool XMLImportHandler::setDeviceTag(XDevice *dev, const QString& ch)
 	// sub circuit input: it's a reference to a device inside
 	// the device name could come in later sections!
 	// the mapping will be done while doing device import for this circuit device
-	if (id == XmlObject::IN_ID) {
+	if (id == XmlSymbol::IN_ID) {
 		int input_id_old = ch.toInt();
 		dev->addInputName(ch, activePos, input_id_old);
 		return true;
 	}
 
 	// device width: net and equ only
-	if (id == XmlObject::WIDTH) {
+	if (id == XmlSymbol::WIDTH) {
 		int width = ch.toInt();
 		dev->setWidth(width);
 		return true;
 	}
 
 	// device width: net and equ only
-	if (id == XmlObject::BUSTYPE) {
+	if (id == XmlSymbol::BUSTYPE) {
 		bool bMux = ch.toInt();
 		dev->setMux(bMux);
 		return true;
 	}
 
-	if (id == XmlObject::CREATION_DATE ||
-		id == XmlObject::UPDATE_DATE ||
-		id == XmlObject::AUTHOR ||
-		id == XmlObject::COMMENT) return true;
+	if (id == XmlSymbol::CREATION_DATE ||
+		id == XmlSymbol::UPDATE_DATE ||
+		id == XmlSymbol::AUTHOR ||
+		id == XmlSymbol::COMMENT) return true;
 
 	error_msg += "XMLImportHandler::setDeviceTag ";
 	error_msg += i18n("error: tag ");
@@ -872,15 +872,15 @@ bool XMLImportHandler::setDeviceTag(XDevice *dev, const QString& ch)
 
 bool XMLImportHandler::endElement(const QString&, const QString&, const QString& qName)
 {
-	int id = XmlObject::getID(qName);
+	int id = XmlSymbolMap::m_oMap[qName];
 
-	if (id == XmlObject::DEV_CONN)
+	if (id == XmlSymbol::DEV_CONN)
 		activeDevConn = (XWire *)NULL;
 
-	if (id == XmlObject::WIRE_CONN)
+	if (id == XmlSymbol::WIRE_CONN)
 		activeWireConn = (XWire *)NULL;
 
-	if (id == XmlObject::DEVICE) {
+	if (id == XmlSymbol::DEVICE) {
 		activeDev->parseEquation();
 
 		if (activeDev->isTristate())
@@ -895,11 +895,11 @@ bool XMLImportHandler::endElement(const QString&, const QString&, const QString&
 		activeDev = (XDevice *)NULL;
 	}
 
-	if (id == XmlObject::WIRE)
+	if (id == XmlSymbol::WIRE)
 		activeWire->select(imp_selected);
 		activeWire = (XWire *)NULL;
 
-	if (id == XmlObject::CIRCUIT) {
+	if (id == XmlSymbol::CIRCUIT) {
 		// only important in top level circuit
 		if (activeNetIdx == 2) {
 			imp_dx = imp_dx_hidden;
