@@ -28,12 +28,12 @@ XWire::XWire()
 	for(int i=0; i < 2; i++) {
 		in_dev[i] = (XDevice *)NULL;		// devices, to which output from out_dev is delivered to
 		in_id[i] = 0;
-		in_inv[i] = new Device(DeviceType::fINV_INTERNAL);
+		in_inv[i] = 0;
 		input_is_inv[i] = 0;
 
 		out_dev[i] = (XDevice *)NULL;		// devices which may deliver input for this wire
 		out_id[i] = 0;
-		out_inv[i] = new XDevice(DeviceType::fINV_INTERNAL, 0, 0);
+		out_inv[i] = 0;
 		output_is_inv[i] = 0;
 
 		io_wire[i] = (XWire *)NULL;
@@ -52,12 +52,12 @@ XWire::XWire(QPoint p)
 	for(int i=0; i < 2; i++) {
 		in_dev[i] = (XDevice *)NULL;		// devices, to which output from out_dev is delivered to
 		in_id[i] = 0;
-		in_inv[i] = new Device(DeviceType::fINV_INTERNAL);
+		in_inv[i] = 0;
 		input_is_inv[i] = 0;
 
 		out_dev[i] = (XDevice *)NULL;		// devices which may deliver input for this wire
 		out_id[i] = 0;
-		out_inv[i] = new XDevice(DeviceType::fINV_INTERNAL, 0, 0);
+		out_inv[i] = 0;
 		output_is_inv[i] = 0;
 
 		io_wire[i] = (XWire *)NULL;
@@ -77,10 +77,10 @@ XWire::~XWire()
 		removeNode();
 	}
 
-	delete in_inv[0];
-	delete in_inv[1];
-	delete out_inv[0];
-	delete out_inv[1];
+	if (in_inv[0]) delete in_inv[0];
+	if (in_inv[1]) delete in_inv[1];
+	if (out_inv[0]) delete out_inv[0];
+	if (out_inv[1]) delete out_inv[1];
 
 	io_w.Destroy();
 }
@@ -424,10 +424,8 @@ void XWire::disconnectOutput(int idx)
 void XWire::invertInput(XDevice *d, bool set)
 {	int idx;
 
-	if (WFAIL == (idx = getInputIndex(d))) {
-		fprintf(stderr, "device %s ..\n", d->getText());
+	if (WFAIL == (idx = getInputIndex(d)))
 		fatal("XWire::invertInput: unknown device");
-	}
 
 	// nothing to do?
 	if (input_is_inv[idx] && set == TRUE) return;
@@ -514,6 +512,9 @@ void XWire::setDeviceConnection(int whatsnew, int type, int in_idx, XDevice *out
 	// input inverter connection/disconnection
 	if (!output_device || whatsnew == NEW_INPUT) {
 		if (input_is_inv[in_idx]) {
+			if (type == CONNECT && !in_inv[in_idx])
+				in_inv[in_idx] = new Device(DeviceType::fINV_INTERNAL);
+
 			if (type == CONNECT) in_dev[in_idx]->connectDevices(in_inv[in_idx], in_id[in_idx], 0);
 			if (type == DISCONN) in_dev[in_idx]->disconnectDevices(in_inv[in_idx], in_id[in_idx], 0);
 		}
@@ -531,6 +532,9 @@ void XWire::setDeviceConnection(int whatsnew, int type, int in_idx, XDevice *out
 
 	// device connection/disconnection
 	if (input_is_inv[in_idx]) {
+		if (type == CONNECT && !in_inv[in_idx])
+			in_inv[in_idx] = new Device(DeviceType::fINV_INTERNAL);
+
 		if (type == CONNECT) in_inv[in_idx]->connectDevices(output_device, 0, output_id);
 		if (type == DISCONN) in_inv[in_idx]->disconnectDevices(output_device, 0, output_id);
 	} else {
@@ -724,6 +728,8 @@ void XWire::scanOutputDev()
 		if (out_dev[0]) {
 			if (output_is_inv[0]) {
 				resetScanAdd(START);
+				if (!out_inv[0])
+					out_inv[0] = new XDevice(DeviceType::fINV_INTERNAL, 0, 0);
 				addOutputDev(out_inv[0], 0);
 			} else {
 				resetScanAdd(START);
@@ -734,6 +740,8 @@ void XWire::scanOutputDev()
 		if (out_dev[1]) {
 			if (output_is_inv[1]) {
 				resetScanAdd(START);
+				if (!out_inv[1])
+					out_inv[1] = new XDevice(DeviceType::fINV_INTERNAL, 0, 0);
 				addOutputDev(out_inv[1], 0);
 			} else {
 				resetScanAdd(START);
@@ -773,10 +781,6 @@ void XWire::removeOutputDev(XDevice *dev, int dev_id)
 			lw->Get()->removeOutputDev(dev, dev_id);
 			lw = lw->Next();
 		}
-
-		// set line size if it is a bus
-		if (dev->type() == DeviceType::fBUS && !dev->isMux())
-			setLineSize(3);
 	}
 }
 
@@ -795,13 +799,6 @@ void XWire::addOutputDev(XDevice *dev, int dev_id)
 			lw->Get()->addOutputDev(dev, dev_id);
 			lw = lw->Next();
 		}
-
-		// set line size if it is a bus
-		if (dev->type() == DeviceType::fBUS  && !dev->isMux()) {
-			setLineSize(3);
-		} else {
-			setLineSize(1);
-		}
 	}
 }
 
@@ -840,25 +837,33 @@ void XWire::resetScan(bool start)
 // 0:      nothing changed
 int XWire::setColor(bool force)
 {	KlogicList<XDevice> *ld = wire_devs.First();
-	XDevice *wire_dev;
-	int wire_id;
+	XDevice *oWireDev;
+	int iOutputID;
 	int found = 0;
 
 	while(ld) {
-		wire_dev = ld->Get();
-		wire_id = ld->getID1();
+		oWireDev = ld->Get();
+		iOutputID = ld->getID1();
+
+		// check wether wire should be fat or normal size
+		if (oWireDev->hasBooleanOutput(iOutputID)) {
+			setLineSize(1);
+		} else {
+			cout << "size 3" << endl;
+			setLineSize(3);
+		}
 
 		// check here if output is active (tristate!)
-		if (wire_dev->outputIsActive(wire_id) || force) {
+		if (oWireDev->outputIsActive(iOutputID) || force) {
 			if (found) {
 				Wire::color = Qt::cyan;
 				return WSHORT;
 			}
 
 			found++;
-			if (wire_dev->outputChanged() || force || 
+			if (oWireDev->outputChanged() || force || 
 			    (Wire::color != Qt::blue && Wire::color != Qt::red)) {
-				if (wire_dev->output(wire_id)) {
+				if (oWireDev->output(iOutputID)) {
 					Wire::color = Qt::red;
 					return WOK;
 				} else {
@@ -867,10 +872,12 @@ int XWire::setColor(bool force)
 				}
 			}
 		}
+
 		ld = ld->Next();
 	}
 
 	if (!found) {
+		setLineSize(1);
 		if (Wire::color != Qt::black) {
 			Wire::color = Qt::black;
 			return WOK;
